@@ -11,6 +11,11 @@
 ** by choosing "define as button" from the context menu of an 
 ** MenuObject.
 **
+**   Created : 
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ****************************************************************************/
 
 #include <qtimer.h>
@@ -22,6 +27,7 @@
 #include "global.h"
 #include "xml_dvd.h"
 #include "menupreview.h"
+#include "maskobject.h"
 #include "dialogbutton.h"
 #include "menuobject.h"
 #include "textobject.h"
@@ -35,36 +41,47 @@
 ButtonObject::ButtonObject (QWidget *pParent) //, const char *pName, WFlags flags)
 	: MenuObject (pParent)
 {
-	m_qsObjectType = QString (BUTTON_OBJECT);
-	m_iButtonState = STATE_NORMAL;
+	m_qsObjectType     = QString (BUTTON_OBJECT);
+	m_iButtonState     = STATE_NORMAL;
 	m_pSourceFileEntry = NULL;
-	m_bMoveable = true;
+	m_bMoveable        = true;
+	m_bLoopMultiple    = false;
 }
 
-ButtonObject::~ButtonObject ()
+ButtonObject::~ButtonObject ( )
 {
-	// Please note that the m_listNormalState etc objects are not destroyed here
-	// As this is merely a holding place for the Objects.
-	// Creation and destruction is done in the Parent (MenuPreview / ButtonPreview etc.)
+  uint t;
+  for ( t=0; t<m_listHighlightedState.count ( ); t++ )
+    delete m_listHighlightedState[t];
+  for ( t=0; t<m_listSelectedState.count ( ); t++ )
+    delete m_listSelectedState[t];
+  for ( t=0; t<m_listNormalState.count ( ); t++ )
+    delete m_listNormalState[t];
+
+  m_listNormalState.clear ( );
+  m_listSelectedState.clear ( );
+  m_listHighlightedState.clear ( );
 }
 
-MenuObject *ButtonObject::clone ( QWidget *pParent )
+MenuObject *ButtonObject::clone ( QWidget *pParent, MenuObject * )
 {
   if ( ! pParent )
     pParent = MenuObject::parent ( );
   uint t;
   ButtonObject *pNewObject = new ButtonObject ( pParent );
-  for (t=0;t<m_listNormalState.count();t++)
-    pNewObject->appendNormal (m_listNormalState[t]->clone ( pParent ) );
-  for (t=0;t<m_listSelectedState.count();t++)
-    pNewObject->appendSelected (m_listSelectedState[t]->clone ( pParent ) );
-  for (t=0;t<m_listHighlightedState.count();t++)
-    pNewObject->appendHighlighted (m_listHighlightedState[t]->clone ( pParent ) );
+  for ( t=0; t<m_listNormalState.count ( ); t++ )
+    pNewObject->appendNormal ( m_listNormalState[t]->clone ( pParent, pNewObject ) );
+  for ( t=0; t<m_listSelectedState.count ( ); t++ )
+    pNewObject->appendSelected ( m_listSelectedState[t]->clone ( pParent, pNewObject ) );
+  for ( t=0; t<m_listHighlightedState.count ( ); t++ )
+    pNewObject->appendHighlighted ( m_listHighlightedState[t]->clone ( pParent, pNewObject ) );
   
   pNewObject->setSourceFileEntry(sourceFileEntry());
   pNewObject->setAction   ( action    ( ) );
   pNewObject->setPreAction( preAction ( ) );
   pNewObject->setName     ( name      ( ) );
+  pNewObject->setPlayMultipleList( getPlayMultipleList ( ) );
+  pNewObject->setLoopMultiple    ( getLoopMultiple     ( ) );
   pNewObject->setNext     ( NEXT_BUTTON_UP,    m_qsUp    );
   pNewObject->setNext     ( NEXT_BUTTON_DOWN,  m_qsDown  );
   pNewObject->setNext     ( NEXT_BUTTON_RIGHT, m_qsRight );
@@ -77,14 +94,16 @@ ButtonObject &ButtonObject::operator = (ButtonObject &theOther)
 {
 	uint t;
 	clear ();
-	setSourceFileEntry(theOther.sourceFileEntry());
-	m_qsAction    = theOther.action();
-	m_qsPreAction = theOther.preAction();
-	m_qsName      = theOther.name();
-	m_qsUp        = theOther.next(NEXT_BUTTON_UP);
-	m_qsDown      = theOther.next(NEXT_BUTTON_DOWN);
-	m_qsRight     = theOther.next(NEXT_BUTTON_RIGHT);
-	m_qsLeft      = theOther.next(NEXT_BUTTON_LEFT);
+	setSourceFileEntry ( theOther.sourceFileEntry ( ) );
+	m_qsAction    = theOther.action    ( );
+	m_qsPreAction = theOther.preAction ( );
+	m_qsName      = theOther.name      ( );
+	m_qsUp        = theOther.next ( NEXT_BUTTON_UP    );
+	m_qsDown      = theOther.next ( NEXT_BUTTON_DOWN  );
+	m_qsRight     = theOther.next ( NEXT_BUTTON_RIGHT );
+	m_qsLeft      = theOther.next ( NEXT_BUTTON_LEFT  );
+	m_listPlayMultiple = theOther.getPlayMultipleList ( );
+	m_bLoopMultiple    = theOther.getLoopMultiple     ( );
 	// The following lists hold the information for the different button states.
 	for (t=0;t<theOther.getNormalCount();t++)
 		appendNormal(theOther.getNormal(t));
@@ -107,21 +126,22 @@ void ButtonObject::clear ()
 	m_qsRight      = QString ("");
 	m_qsLeft       = QString ("");
 	m_pSourceFileEntry = NULL;
+	m_listPlayMultiple.clear ( );
 
-	for (t=0;t<m_listNormalState.count();t++)
+	for ( t=0; t<m_listNormalState.count ( ); t++ )
 		delete m_listNormalState[t];
-	for (t=0;t<m_listSelectedState.count();t++)
+	for ( t=0; t<m_listSelectedState.count ( ); t++ )
 		delete m_listSelectedState[t];
-	for (t=0;t<m_listHighlightedState.count();t++)
+	for ( t=0; t<m_listHighlightedState.count ( ); t++ )
 		delete m_listHighlightedState[t];
-	m_listNormalState.clear();
-	m_listSelectedState.clear();
-	m_listHighlightedState.clear();
+	m_listNormalState.clear  ( );
+	m_listSelectedState.clear  ( );
+	m_listHighlightedState.clear ( );
 }
 
 void ButtonObject::drawContents (QPainter *pPainter)
 {
-	drawContents(pPainter, BACKGROUND_IMG);
+	drawContents ( pPainter, BACKGROUND_IMG );
 //	m_listNormalState[0]->drawContents(pPainter);
 //	m_boundingRect = m_listNormalState[0]->boundingRect();
 //	m_rect = m_listNormalState[0]->rect();
@@ -129,23 +149,23 @@ void ButtonObject::drawContents (QPainter *pPainter)
 
 void ButtonObject::drawContents (QPainter *pPainter, uint iWhichState)
 {
-	switch (iWhichState)	{
-	case BACKGROUND_IMG:
-		if (m_listNormalState[0])	{
-			m_listNormalState[0]->drawContents(pPainter);
-			m_boundingRect = m_listNormalState[0]->boundingRect();
-			m_rect = m_listNormalState[0]->rect();
-		}
-	break;
-	case HIGHLIGHTED_MASK:
-		if (m_listHighlightedState[0])
-			m_listHighlightedState[0]->drawContents(pPainter);
-	break;
-	case SELECTED_MASK:
-		if (m_listSelectedState[0])
-			m_listSelectedState[0]->drawContents(pPainter);
-	break;
-	}
+  switch ( iWhichState )  {
+  case BACKGROUND_IMG:
+    if ( m_listNormalState[0] )	{
+      m_listNormalState[0]->drawContents ( pPainter );
+      m_boundingRect = m_listNormalState [0]->boundingRect ( );
+      m_rect = m_listNormalState[0]->rect( );
+    }
+    break;
+  case HIGHLIGHTED_MASK:
+    if ( m_listHighlightedState[0] )
+      m_listHighlightedState[0]->drawContents ( pPainter );
+    break;
+  case SELECTED_MASK:
+    if ( m_listSelectedState[0] )
+      m_listSelectedState[0]->drawContents ( pPainter );
+    break;
+  }
 }
 
 void ButtonObject::drawContents (QPainter *pPainter, int iRenderFrameNumber, int iTotalFrames)
@@ -285,45 +305,171 @@ void ButtonObject::appendHighlighted (MenuObject *pObject)
 	m_listHighlightedState.append (pObject);
 }
 
-uint ButtonObject::getNormalCount ()
+Rgba ButtonObject::getMaskColor ( bool bHighlighted, int iIdx )
 {
-	return m_listNormalState.count();
+  Rgba returnColor ( 0, 0, 0, 0 );
+  MenuObject *pObject = NULL;
+  if ( bHighlighted ) {
+    if ( iIdx >= (int)m_listHighlightedState.count ( ) )
+      return returnColor;
+    pObject = m_listHighlightedState[iIdx];
+  }
+  else {
+    if ( iIdx >= (int)m_listSelectedState.count ( ) )
+      return returnColor;
+    pObject = m_listSelectedState[iIdx];
+  }
+
+  if ( pObject->objectType ( ) == MASK_OBJECT ) {
+    MaskObject   *pMask = (MaskObject *)pObject;
+    returnColor = pMask->color ( );
+  }
+  else if ( pObject->objectType ( ) == FRAME_OBJECT ) {
+    FrameObject  *pFrame = (FrameObject *)pObject;
+    returnColor = pFrame->color ( );
+  }
+  else if ( pObject->objectType ( ) == TEXT_OBJECT ) {
+    TextObject   *pText = (TextObject *)pObject;
+    returnColor = pText->getForegroundColor ( );
+  }
+  return returnColor;
 }
 
-MenuObject *ButtonObject::getNormal (int iNr)
+bool ButtonObject::setMaskColor ( Rgba newColor, bool bHighlighted, int iIdx )
 {
-	if (iNr > (int)m_listNormalState.count())
-		return NULL;
-	return m_listNormalState[iNr];
+  MenuObject *pObject = NULL;
+  if ( bHighlighted ) {
+    if ( iIdx >= (int)m_listHighlightedState.count ( ) )
+      return false;
+    pObject = m_listHighlightedState[iIdx];
+  }
+  else {
+    if ( iIdx >= (int)m_listSelectedState.count ( ) )
+      return false;
+    pObject = m_listSelectedState[iIdx];
+  }
+
+  if ( pObject->objectType ( ) == MASK_OBJECT ) {
+    MaskObject  *pMask = (MaskObject *)pObject;
+    pMask->setColor ( newColor );
+  }
+  else if ( pObject->objectType ( ) == FRAME_OBJECT ) {
+    FrameObject *pFrame = (FrameObject *)pObject;
+    pFrame->setFrameColor ( newColor );
+  }
+  else if ( pObject->objectType ( ) == TEXT_OBJECT ) {
+    TextObject  *pText = (TextObject *)pObject;
+    pText->setForegroundColor ( newColor );
+  }
+  else
+    return false;
+  return true;
+}
+
+uint ButtonObject::getNormalCount ()
+{
+  return m_listNormalState.count();
+}
+
+MenuObject *ButtonObject::getNormal ( uint iNr )
+{
+  if ( iNr >= m_listNormalState.count ( ) )
+    return NULL;
+  return m_listNormalState[iNr];
+}
+
+MenuObject *ButtonObject::removeNormal ( uint iNr )
+{
+  MenuObject *pMenuObject = getNormal ( iNr );
+  if ( pMenuObject )
+    m_listNormalState.remove ( pMenuObject );
+  return pMenuObject;
+}
+
+bool ButtonObject::removeNormal ( MenuObject *pMenuObject )
+{
+  if ( ! pMenuObject )
+    return false;
+  return m_listNormalState.remove ( pMenuObject );
 }
 
 uint ButtonObject::getSelectedCount ()
 {
-	return m_listSelectedState.count();
+  return m_listSelectedState.count();
 }
 
-MenuObject *ButtonObject::getSelected (int iNr)
+MenuObject *ButtonObject::getSelected ( uint iNr )
 {
-	if (iNr > (int)m_listSelectedState.count())
-		return NULL;
-	return m_listSelectedState[iNr];
+  if ( iNr >= m_listSelectedState.count ( ) )
+    return NULL;
+  return m_listSelectedState[iNr];
+}
+
+MenuObject *ButtonObject::removeSelected ( uint iNr )
+{
+  MenuObject *pMenuObject = getSelected ( iNr );
+  if ( pMenuObject )
+    m_listSelectedState.remove ( pMenuObject );
+  return pMenuObject;
+}
+
+bool ButtonObject::removeSelected ( MenuObject *pMenuObject )
+{
+  if ( ! pMenuObject )
+    return false;
+  return m_listSelectedState.remove ( pMenuObject );
 }
 
 uint ButtonObject::getHighlightedCount ()
 {
-	return m_listHighlightedState.count();
+  return m_listHighlightedState.count();
 }
 
-MenuObject *ButtonObject::getHighlighted (int iNr)
+MenuObject *ButtonObject::getHighlighted ( uint iNr )
 {
-	if (iNr > (int)m_listHighlightedState.count())
-		return NULL;
-	return m_listHighlightedState[iNr];
+  if ( iNr >= m_listHighlightedState.count ( ) )
+    return NULL;
+  return m_listHighlightedState[iNr];
+}
+
+MenuObject *ButtonObject::removeHighlighted ( uint iNr )
+{
+  MenuObject *pMenuObject = getHighlighted ( iNr );
+  if ( pMenuObject )
+    m_listHighlightedState.remove ( pMenuObject );
+  return pMenuObject;
+}
+
+bool ButtonObject::removeHighlighted ( MenuObject *pMenuObject )
+{
+  if ( ! pMenuObject )
+    return false;
+  return m_listHighlightedState.remove ( pMenuObject );
+}
+
+QStringList &ButtonObject::getPlayMultipleList ( )
+{
+  return m_listPlayMultiple;
+}
+
+void ButtonObject::setPlayMultipleList ( QStringList &newList )
+{
+  m_listPlayMultiple = newList;
+}
+
+bool ButtonObject::getLoopMultiple ( )
+{
+  return m_bLoopMultiple;
+}
+
+void ButtonObject::setLoopMultiple ( bool bLoopMultiple )
+{
+  m_bLoopMultiple = bLoopMultiple;
 }
 
 void ButtonObject::deleteMasks()
 {
-	// This function handles only the case of the cancelation of the Button creation
+	// This function only handles the case of the cancelation of the Button creation
 	// From the DialogButton - class.
 	// I.e. the user just created the Button and decides to cancel out.
 	// In case the User cancels the ButtonDialog when the ButtonObject already 
@@ -339,11 +485,12 @@ void ButtonObject::deleteMasks()
 	m_listHighlightedState.clear();
 }
 
-bool ButtonObject::readProjectFile  (QDomNode &theNode)
+bool ButtonObject::readProjectFile ( QDomNode &theNode )
 {
 	// Okay, here we retain the stored data from the xml file.
-	QDomElement theElement = theNode.toElement();
-	QDomAttr attribute;
+	QDomNode    xmlMultiple = theNode.firstChild ( );
+	QDomElement theElement  = theNode.toElement();
+	QDomAttr    attribute;
 
 	attribute = theElement.attributeNode ( BUTTON_OBJECT_NAME );
 	if (!attribute.isNull())
@@ -391,6 +538,14 @@ bool ButtonObject::readProjectFile  (QDomNode &theNode)
 	attribute = theElement.attributeNode ( BUTTON_OBJECT_SOURCE_ENTRY);
 	if (!attribute.isNull())
 		m_qsSourceDisplayName = attribute.value();
+
+	attribute = theElement.attributeNode ( BUTTON_OBJECT_LOOP_MULTIPLE );
+	m_bLoopMultiple = false;
+	if ( ! attribute.isNull ( ) ) {
+	  if ( attribute.value  ( ) == QString ("true") )
+	    m_bLoopMultiple = true;
+	}
+
 	// Please note that the nortmal / selected / highlighted objects are read
 	// in by ButtonObject::readObjects(...);
 	return true;
@@ -398,36 +553,66 @@ bool ButtonObject::readProjectFile  (QDomNode &theNode)
 
 bool ButtonObject::readObjects (QDomNode &theNode, MenuPreview *pPreview)
 {
-	QDomElement buttonElement;
-	QDomNode buttonNode = theNode.firstChild();
-	QDomNode childNode;
-	MenuObject *pNewObject = NULL;
-	while (!buttonNode.isNull())	{
-		buttonElement   = buttonNode.toElement();
-		QString tagName = buttonElement.tagName();
-		childNode = buttonNode.firstChild();
-		// Next we should create the new Object but if we see the
-		// MenoObject tag it means it is the MenuObject vars of the button
-		// itself, thus we don't want to create anything. (It would put out a warning).
-		if (tagName != MENU_OBJECT)
-			pNewObject = pPreview->readObject ( childNode );
-		if (tagName == BUTTON_OBJECT_NORMAL)
-			m_listNormalState.append ( pNewObject );
+  int t;
+  QDomElement buttonElement;
+  QDomNode    childNode;
+  QDomNode    buttonNode = theNode.firstChild();
+  MenuObject *pNewObject = NULL;
+  MenuObject *pMenuObject;
+  while ( ! buttonNode.isNull ( ) )  {
+    buttonElement   = buttonNode.toElement  ( );
+    QString tagName = buttonElement.tagName ( );
+    if ( buttonElement.hasChildNodes ( ) ) { // For Masks we do not need any children.
+      childNode = buttonNode.firstChild ( );
+      // Next we should create the new Object but if we see the
+      // MenoObject tag it means it is the MenuObject vars of the button
+      // itself, thus we don't want to create anything. (It would put out a warning).
+      if ( tagName == BUTTON_OBJECT_MULTIPLE ) {
+	QString nodeText = buttonElement.text ( );
+	m_listPlayMultiple.append ( nodeText );
+      }
+      else if ( tagName != MENU_OBJECT ) 
+	pNewObject = pPreview->readObject ( childNode );
 
-		else if (tagName == BUTTON_OBJECT_SELECTED)
-			m_listSelectedState.append( pNewObject );
+      if ( tagName == BUTTON_OBJECT_NORMAL )
+	m_listNormalState.append ( pNewObject );
+      
+      else if ( tagName == BUTTON_OBJECT_SELECTED )
+	m_listSelectedState.append( pNewObject );
+      
+      else if ( tagName == BUTTON_OBJECT_HIGHLIGHTED )
+	m_listHighlightedState.append ( pNewObject );
+      
+      else if ( tagName == MENU_OBJECT )
+	MenuObject::readProjectFile( theNode );
+      
+      else if ( tagName != BUTTON_OBJECT_MULTIPLE )
+	printf ("Warning : ButtonObject::readObjects -=> wrong XML Node <%s>\nContinuing ...\n", (const char *)tagName);
+    }
+    buttonNode = buttonNode.nextSibling ();
+  }
 
-		else if (tagName == BUTTON_OBJECT_HIGHLIGHTED)
-			m_listHighlightedState.append ( pNewObject );
-
-		else if (tagName == MENU_OBJECT)
-			MenuObject::readProjectFile( theNode );
-
-		else
-			printf ("Warning : ButtonObject::readObjects -=> wrong XML Node <%s>\nContinuing ...\n", (const char *)tagName);
-		buttonNode = buttonNode.nextSibling ();
-	}
-	return true;
+  // short sanity check ..
+  if ( m_listNormalState.count ( ) < 1 )
+    return false;
+ 
+  MaskObject *pMask = NULL;
+  MenuObject *pParentObject = m_listNormalState[0];
+  for ( t=0; t<(int)m_listSelectedState.count ( ); t++ ) {
+    pMenuObject = m_listSelectedState[t];
+    if ( pMenuObject->objectType ( ) == QString ( MASK_OBJECT ) ) {
+      pMask = (MaskObject *)pMenuObject;
+      pMask->setParent ( pParentObject );
+    }
+  }
+  for ( t=0; t<(int)m_listHighlightedState.count ( ); t++ ) {
+    pMenuObject = m_listHighlightedState[t];
+    if ( pMenuObject->objectType ( ) == QString ( MASK_OBJECT ) ) {
+      pMask = (MaskObject *)pMenuObject;
+      pMask->setParent ( pParentObject );
+    }
+  } 
+  return true;
 }
 
 bool ButtonObject::writeProjectFile (QDomElement &theElement)
@@ -452,29 +637,39 @@ bool ButtonObject::writeProjectFile (QDomElement &theElement)
 		buttonNode.setAttribute( BUTTON_OBJECT_RIGHT,  m_qsRight );
 	if (!m_bMoveable)
 		buttonNode.setAttribute( BUTTON_OBJECT_MOVEABLE, QString ("false") );
+	if ( m_bLoopMultiple )
+		buttonNode.setAttribute( BUTTON_OBJECT_LOOP_MULTIPLE, QString ("true") );
 
 	if (m_pSourceFileEntry)
 		buttonNode.setAttribute( BUTTON_OBJECT_SOURCE_ENTRY,  m_pSourceFileEntry->qsDisplayName );
 //printf ("ButtonObject::writeProjectFile <%s> - <%s> \n", (const char *)m_pSourceFileEntry->qsDisplayName, (const char *)m_qsAction );
+	
+	// And here we store the list of multiple objects ( if present )
+	for ( t=0; t<m_listPlayMultiple.count ( ); t++ ) {
+	  QDomElement multipleNode = xmlDoc.createElement  ( BUTTON_OBJECT_MULTIPLE );
+	  QDomText text = xmlDoc.createTextNode ( m_listPlayMultiple[t] );
+	  multipleNode.appendChild ( text );
+	  buttonNode.appendChild ( multipleNode );
+	}
 
 	// And here we store the ButtonObjects children ...
-	QDomElement normalNode = xmlDoc.createElement( BUTTON_OBJECT_NORMAL );
-	for (t=0;t<m_listNormalState.count();t++)
-		m_listNormalState[t]->writeProjectFile ( normalNode );
+	QDomElement normalNode = xmlDoc.createElement      ( BUTTON_OBJECT_NORMAL );
+	for ( t=0; t<m_listNormalState.count ( ); t++ )
+	  m_listNormalState[t]->writeProjectFile ( normalNode );
 
-	QDomElement selectedNode = xmlDoc.createElement( BUTTON_OBJECT_SELECTED );
-	for (t=0;t<m_listSelectedState.count();t++)
-		m_listSelectedState[t]->writeProjectFile ( selectedNode );
+	QDomElement selectedNode = xmlDoc.createElement    ( BUTTON_OBJECT_SELECTED );
+	for ( t=0; t<m_listSelectedState.count ( ); t++ )
+	  m_listSelectedState[t]->writeProjectFile ( selectedNode );
 
-	QDomElement highlightedNode = xmlDoc.createElement( BUTTON_OBJECT_HIGHLIGHTED );
+	QDomElement highlightedNode = xmlDoc.createElement ( BUTTON_OBJECT_HIGHLIGHTED );
 	for (t=0;t<m_listHighlightedState.count();t++)
-		m_listHighlightedState[t]->writeProjectFile ( highlightedNode );
+	  m_listHighlightedState[t]->writeProjectFile ( highlightedNode );
 
-	buttonNode.appendChild( normalNode );
-	buttonNode.appendChild( selectedNode );
-	buttonNode.appendChild( highlightedNode );
+	buttonNode.appendChild ( normalNode      );
+	buttonNode.appendChild ( selectedNode    );
+	buttonNode.appendChild ( highlightedNode );
 	
-	theElement.appendChild( buttonNode );
+	theElement.appendChild ( buttonNode );
 	// And here we write the base class ...
 	return MenuObject::writeProjectFile( buttonNode );
 }
@@ -541,15 +736,35 @@ bool ButtonObject::createContextMenu (QPoint globalPos)
 		return true;
 }
 
-void ButtonObject::createStructure (QListViewItem *pParentItem)
+void ButtonObject::createMask ( Rgba *pPgcColors )
+{
+  MaskObject *pMask   = NULL;
+  MenuObject *pParent = getNormal  ( 0 );
+  if ( ( ! pParent ) || ( ! pPgcColors ) )
+    return;
+
+  pMask = new MaskObject ( pParent, MenuObject::parent ( ) );
+  pMask  ->setColor      ( pPgcColors[1] );
+  pMask  ->updateMask    ( );
+  appendHighlighted      ( pMask );
+
+  pMask = new MaskObject ( pParent, MenuObject::parent ( ) );
+  pMask  ->setColor      ( pPgcColors[2] );
+  pMask  ->updateMask    ( );
+  appendSelected         ( pMask );
+}
+
+StructureItem *ButtonObject::createStructure ( StructureItem *pParentItem )
 {
   // Creating teh ListView structure of this Button.
-  StructureItem *pButtonItem;
-  StructureItem *pStateItem;
+  StructureItem *pStateItem, *pTemp=NULL;
 
   QString qsAction;
   QStringList actionList;
-  if (!m_qsAction.isEmpty())	{	// For new buttons this might be empty ...
+  
+  if ( m_listPlayMultiple.count ( ) > 1 )
+    qsAction = tr ( "Play Multiple Files" );
+  else if ( ! m_qsAction.isEmpty ( ) ) { // For new buttons this might be empty ...
     actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
     if (actionList.count() == 1)	
       qsAction = m_qsAction;
@@ -559,26 +774,52 @@ void ButtonObject::createStructure (QListViewItem *pParentItem)
 	qsAction += QString (" ") +actionList[3];
     }
   }
-  pButtonItem = new StructureItem(this, pParentItem, m_qsName, qsAction);
-  pButtonItem->setExpandable (TRUE);
+  if ( ! m_pStructureItem ) {
+    m_pStructureItem = new StructureItem ( this, pParentItem, pParentItem->lastChild ( ), m_qsName, qsAction );
+    m_pStructureItem->setExpandable      ( TRUE );
+  }
+  else
+    m_pStructureItem->setText ( m_qsName, qsAction );
   
   uint t;
-  for (t=0;t<m_listHighlightedState.count();t++)	{
-    pStateItem = new StructureItem(this, pButtonItem, QString ("Highlighted"), QString (""));
-    pStateItem->setExpandable (TRUE);
-    m_listHighlightedState[t]->createStructure ( pStateItem );
+  QString qsEmpty;
+  QString qsHighlighted = tr ( "Highlighted" );
+  QString qsSelected    = tr ( "Selected" );
+
+  for ( t=0; t<m_listNormalState.count ( ); t++ )
+    pTemp = m_listNormalState[t]->createStructure ( m_pStructureItem );
+
+  pStateItem =(StructureItem *) m_pStructureItem->firstChild ( );
+  while ( pStateItem )  {
+    if  ( pStateItem->text ( 0 ) == qsHighlighted )
+      break;
+    pStateItem = (StructureItem *)pStateItem->nextSibling ( );
   }
-  for (t=0;t<m_listSelectedState.count();t++)	{
-    pStateItem = new StructureItem(this, pButtonItem, QString ("Selected"), QString (""));
-    pStateItem->setExpandable (TRUE);
-    m_listSelectedState[t]->createStructure ( pStateItem );
+  if ( ! pStateItem ) {
+    pStateItem = new StructureItem ( this, m_pStructureItem, pTemp, qsHighlighted, qsEmpty );
+    pStateItem->setExpandable ( TRUE );
   }
-  for (t=0;t<m_listNormalState.count();t++)	{
-    m_listNormalState[t]->createStructure ( pButtonItem );
+  for ( t=0; t<m_listHighlightedState.count ( ); t++ )
+    pTemp = m_listHighlightedState[t]->createStructure ( pStateItem );
+
+  pTemp = pStateItem;
+  pStateItem =(StructureItem *) m_pStructureItem->firstChild ( );
+  while ( pStateItem )  {
+    if  ( pStateItem->text ( 0 ) == qsSelected )
+      break;
+    pStateItem = (StructureItem *)pStateItem->nextSibling ( );
   }
+  if ( ! pStateItem ) {
+    pStateItem = new StructureItem ( this, m_pStructureItem, pTemp, qsSelected, qsEmpty );
+    pStateItem->setExpandable ( TRUE );
+  }
+  for ( t=0; t<m_listSelectedState.count ( ); t++ )
+    pTemp = m_listSelectedState[t]->createStructure ( pStateItem );
+
+  return m_pStructureItem;
 }
 
-void ButtonObject::replaceColor (QColor theColor, QColor oldColor)
+void ButtonObject::replaceColor ( Rgba theColor, Rgba oldColor )
 {
 	// We handle the actual color as a unique index. Thus we allow 
 	// the user to utilise any of the 4 available colors for any purpose.
@@ -589,10 +830,10 @@ void ButtonObject::replaceColor (QColor theColor, QColor oldColor)
 //		m_listNormalState[t]->replaceColor (theColor);
 //	}
 	for (t=0;t<m_listSelectedState.count();t++)	{
-		m_listSelectedState[t]->replaceColor (theColor, oldColor);
+		m_listSelectedState[t]->replaceColor ( theColor, oldColor );
 	}
 	for (t=0;t<m_listHighlightedState.count();t++)	{
-		m_listHighlightedState[t]->replaceColor (theColor, oldColor);
+		m_listHighlightedState[t]->replaceColor ( theColor, oldColor );
 	}
 }
 
@@ -653,35 +894,36 @@ QString &ButtonObject::sourceDisplayName ()
 
 SourceFileEntry *ButtonObject::sourceFileEntry()
 {
-	return m_pSourceFileEntry;
+  return m_pSourceFileEntry;
 }
 
-SourceFileInfo *ButtonObject::sourceFileInfo()
+SourceFileInfo *ButtonObject::sourceFileInfo ( )
 {
-  uint            t;
-  QString         qsName;
-  QFileInfo       fileInfo;
-  QStringList     actionList;
-  SourceFileInfo *pInfo = NULL;
+  uint             t;
+  QString          qsName;
+  QFileInfo        fileInfo;
+  QStringList      actionList;
+  SourceFileEntry *pEntry = sourceFileEntry ( );
+  SourceFileInfo  *pInfo  = NULL;
 
-  if ( ! m_pSourceFileEntry )
+  if  (  ! pEntry )
     return pInfo;
 
   // default to the first info 
-  pInfo = m_pSourceFileEntry->listFileInfos[0];
+  pInfo = pEntry->listFileInfos[0];
 
   if ( ! m_qsAction.isEmpty() )  {  // For new buttons this might be empty ...
-    actionList = QStringList::split (QString (STRING_SEPARATOR), m_qsAction);
-    if (actionList.count() == 4)
-      qsName = actionList[actionList.count() - 2];
-    else if (actionList.count() > 1)
+    actionList = QStringList::split ( QString (STRING_SEPARATOR), m_qsAction );
+    if ( actionList.count ( ) == 4 )
+      qsName = actionList[actionList.count ( ) - 2];
+    else if ( actionList.count ( ) > 1 )
       qsName = actionList[1];
   }
   // find the right sourceFileInfo from the action - string
-  for ( t=0;t<m_pSourceFileEntry->listFileInfos.count();t++ ) {
-    fileInfo.setFile ( m_pSourceFileEntry->listFileInfos[t]->qsFileName );
-    if ( qsName == fileInfo.fileName () )
-      return m_pSourceFileEntry->listFileInfos[t];
+  for ( t=0; t<pEntry->listFileInfos.count ( ); t++ ) {
+    fileInfo.setFile ( pEntry->listFileInfos[t]->qsFileName );
+    if ( qsName == fileInfo.fileName ( ) )
+      return pEntry->listFileInfos[t];
   }
 
   return pInfo;
@@ -703,7 +945,7 @@ int ButtonObject::chapter ( bool bAllEntries )
     return iChapterNumber;
   
   // To get the total chapter number you have to add up the SourceFileInfos
-  // chapters in the SourceFileEntry that come before the actual SourceFIleInfo
+  // chapters in the SourceFileEntry that come before the actual SourceFileInfo
   // on which the button points.
   iChapterNumber = 1;
   if ( bAllEntries ) {
@@ -767,7 +1009,7 @@ QString &ButtonObject::next(uint iNext)
 
 void ButtonObject::slotEdit ( )
 {
-	mouseDoubleClickEvent ( NULL );
+  mouseDoubleClickEvent ( NULL );
 }
 
 void ButtonObject::slotEditObject ( )
@@ -775,6 +1017,7 @@ void ButtonObject::slotEditObject ( )
   MenuObject *pMenuObject = m_listNormalState[0];
   if ( pMenuObject ) {
        pMenuObject->mouseDoubleClickEvent ( NULL );
+
     // Here we handle a special case if the Text / Font of a TextObject has changed
     if ( pMenuObject->objectType ( ) == QString ( TEXT_OBJECT ) ) {
       uint t;
@@ -782,12 +1025,14 @@ void ButtonObject::slotEditObject ( )
       QPoint  align   = pTextObject->getTextAlign ( );
       QString theText = pTextObject->getText ( );
       QFont   theFont = pTextObject->getFont ( );
+      QRect   theRect = pTextObject->rect    ( );
       for ( t=0; t<m_listSelectedState.count ( ); t++ ) {
 	pMenuObject = m_listSelectedState[t];
 	if ( pMenuObject && ( pMenuObject->objectType ( ) == QString ( TEXT_OBJECT ) ) ) {
 	  pTextObject = (TextObject *)pMenuObject;
 	  pTextObject->setText (  theText  );
 	  pTextObject->setFont (  theFont  );
+	  pTextObject->setRect (  theRect  );
 	  pTextObject->setTextAlign( align );
 	}
       }
@@ -797,6 +1042,7 @@ void ButtonObject::slotEditObject ( )
 	  pTextObject = (TextObject *)pMenuObject;
 	  pTextObject->setText (  theText  );
 	  pTextObject->setFont (  theFont  );
+	  pTextObject->setRect (  theRect  );
 	  pTextObject->setTextAlign( align );
 	}
       }
@@ -824,7 +1070,7 @@ void ButtonObject::slotUnbutton ( )
 
 void ButtonObject::slotEmitUnbuttonMe ( )
 {
-  // Here we are going to split the Button object into its three distinkt 
+  // Here we are going to split the Button object into its three distinct 
   // objects and add them to the Preview (MenuPreview that is).
   emit ( signalUnbuttonMe ( this ) );
   // The work is done in MenuPreview::slotUnbutton()
@@ -832,8 +1078,8 @@ void ButtonObject::slotEmitUnbuttonMe ( )
 
 void ButtonObject::slotMoveable()
 {
-	// if it is not moveable the Button is locked in.
-	m_bMoveable = !m_bMoveable;
+  // if it is not moveable the Button is locked in.
+  m_bMoveable = !m_bMoveable;
 }
 
 void ButtonObject::slotAddFrame()
@@ -846,6 +1092,11 @@ void ButtonObject::slotAddImage()
 
 }
 
+void ButtonObject::slotAddMovie() // movie object for the Menu that is ...
+{
+
+}
+
 void ButtonObject::setRect ( QRect &theRect )
 {
   uint t;
@@ -860,19 +1111,14 @@ void ButtonObject::setRect ( QRect &theRect )
 
 QRect &ButtonObject::rect ( )
 {
-  if ( m_listHighlightedState.count ( ) > 0 )
-    return m_listHighlightedState[ 0 ]->rect ( );
+  if ( m_listNormalState.count ( ) > 0 )
+    return m_listNormalState[ 0 ]->rect ( );
 
   return m_rect;
 }
 
-void ButtonObject::slotAddMovie() // movie object for the Menu that is ...
-{
-
-}
-
 AnimationAttribute *ButtonObject::getSpecificAttributes (long, QString)
 {
-	return NULL;
+  return NULL;
 }
 
