@@ -1,8 +1,10 @@
 /****************************************************************************
 ** This is the CommandQueueDialog
 **
-** Created: Wed Mar 31 07:53:05 2004
-**      by: Varol Okan using Kate
+**   Created : Wed Mar 31 07:53:05 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ****************************************************************************/
 #include <sys/stat.h>
@@ -25,6 +27,7 @@
 #include <qwhatsthis.h>
 #include <qregexp.h> 
 
+#include "win32.h"
 #include "execute.h"
 #include "dialogexecute.h"
 #include "dialogman.h"
@@ -32,6 +35,19 @@
 #include "dialogcommandeditor.h"
 #include "messagebox.h"
 
+
+DialogExecute::GuiBlock::GuiBlock ( )
+{
+  pLabelComment          = NULL;
+  pComboTranscode        = NULL;
+  pComboCommands         = NULL;
+  pButtonMan             = NULL;
+  pButtonEdit            = NULL;
+  pButtonSetAsDefault    = NULL;
+  iBlockID               = -1;
+  iBlockExecuteInterface  = -1;
+}
+
 DialogExecute::DialogExecute(QValueList<ExecuteInterface *> listExecuteBlocks, bool bShowDialog )
     : QDialog( )
 {
@@ -79,9 +95,14 @@ printf ("\n\n");
 
 DialogExecute::~DialogExecute()
 {
-	// Destroys the object and frees any allocated resources
-	// no need to delete child widgets, Qt does it all for us
-	delete m_pInitObject;
+  // Destroys the object and frees any allocated resources
+  // no need to delete child widgets, Qt does it all for us
+  int t;
+  for ( t=0; t<(int)m_listGui.count(); t++ )
+    delete m_listGui[t];
+  m_listGui.clear ( );
+
+  delete m_pInitObject;
 }
 
 void DialogExecute::setInit(QDVDAuthorInit *pInit)
@@ -186,7 +207,7 @@ QGridLayout *DialogExecute::createBlockFrame(QWidget *pParent, QGridLayout *pPar
 
 void DialogExecute::createCommandBlock (QWidget *pParent, QGridLayout *pParentLayout, ExecuteInterface *pInterface, int t, int i)
 {
-	int iYPos;
+        int iYPos, iDefaultComment;
 	QLabel		*pComment;
 	QComboBox	*pCommand;
 	QPushButton	*pButton, *pButtonEdit, *pButtonDefault;
@@ -195,10 +216,10 @@ void DialogExecute::createCommandBlock (QWidget *pParent, QGridLayout *pParentLa
 	QVBoxLayout *pEDButtons;
 	// setting : m_listCheckBox/m_listCheckBox2/m_listGroupBox
 	iYPos = 2*i;
-	pEDButtons = new QVBoxLayout( 2, QString ("buttonbox_%1-%2t").arg(t).arg(i));
-	pComment = new QLabel( pParent,   QString ("comment_%1-%2t").arg(t).arg(i));
-	pCommand = new QComboBox( FALSE, pParent, QString ("command_%1-%2t").arg(t).arg(i));
-	pButton  = new QPushButton( pParent, QString ("button_%1-%2t" ).arg(t).arg(i));
+	pEDButtons   = new QVBoxLayout( 2, QString ("buttonbox_%1-%2t").arg(t).arg(i));
+	pComment     = new QLabel( pParent,   QString ("comment_%1-%2t").arg(t).arg(i));
+	pCommand     = new QComboBox( FALSE, pParent, QString ("command_%1-%2t").arg(t).arg(i));
+	pButton      = new QPushButton( pParent, QString ("button_%1-%2t" ).arg(t).arg(i));
 	pButton->setText( tr( "man" ) );
 	pButtonEdit  = new QPushButton( pParent, QString ("button_%1-%2t" ).arg(t).arg(i));
 	pButtonEdit->setMaximumSize ( 25, 25 );
@@ -213,9 +234,19 @@ void DialogExecute::createCommandBlock (QWidget *pParent, QGridLayout *pParentLa
 	}
 	else
 		pCommand->setEditable(TRUE);
-	pCommand->insertStringList (pInterface->listCommandList[i]);
-	pComment->setText          (pInterface->commentList    [i]);
-	pCommand->setCurrentItem   (pInterface->listDefaults   [i]);
+	iDefaultComment = pInterface->listDefaults[i];
+	if ( iDefaultComment >= (int)pInterface->listCommentList[i].count ( ) )
+	     iDefaultComment = 0;
+
+	//for (int x=0; x<pInterface->listCommentList.count ( ); x++ ) {
+	//  for (int y=0;y<pInterface->listCommentList[x].count ( ); y++ ) {
+	//    printf ( "Norm  [%d][%d]=<%s>\n", x, y, pInterface->listCommentList[x][y].ascii () );
+	//  }
+	//}
+
+	pCommand->insertStringList ( pInterface->listCommandList[i] );
+	pComment->setText          ( pInterface->listCommentList[i][iDefaultComment] );
+	pCommand->setCurrentItem   ( pInterface->listDefaults   [i] );
 
 	pEDButtons->addWidget( pButtonEdit );
 	pEDButtons->addWidget( pButtonDefault );
@@ -223,16 +254,21 @@ void DialogExecute::createCommandBlock (QWidget *pParent, QGridLayout *pParentLa
 	pParentLayout->addWidget( pCommand,   1+iYPos, 0 );
 	pParentLayout->addLayout( pEDButtons, 1+iYPos, 1 );
 	pParentLayout->addWidget( pButton,    1+iYPos, 2 );
+	
+	GuiBlock *pGuiBlock               = new GuiBlock;
+	pGuiBlock->listComments           = pInterface->listCommentList[i];
+	pGuiBlock->pComboCommands         = pCommand;
+	pGuiBlock->pLabelComment          = pComment;
+	pGuiBlock->pButtonMan             = pButton;
+	pGuiBlock->pButtonEdit            = pButtonEdit;
+	pGuiBlock->pButtonSetAsDefault    = pButtonDefault;
+	pGuiBlock->iBlockID               = pInterface->listBlockIDs[i];
+	pGuiBlock->iBlockExecuteInterface = t;// this connects the ExecuteInterface with the generated Block
+	m_listGui.append ( pGuiBlock );
 
-	m_listCommandsWidget.append      ( pCommand );
-	m_listCommentsWidget.append      ( pComment );
-	m_listButtonWidgets.append       ( pButton  );
-	m_listButtonEdit.append          ( pButtonEdit );
-	m_listButtonSetAsDefault.append  ( pButtonDefault );
-	m_listBlockID.append             ( pInterface->listBlockIDs[i] );
-	m_listBlockExecuteInterface.append(t);// this connects the ExecuteInterface with the generated Block
-	connect (pButton, SIGNAL(clicked ()), this, SLOT(slotManButtonClicked()));
-	connect (pButtonEdit, SIGNAL(clicked ()), this, SLOT(slotEditButtonClicked()));
+	connect (pCommand,       SIGNAL(activated (int)), this, SLOT(slotNormalSelectionChanged(int)));
+	connect (pButton,        SIGNAL(clicked ()), this, SLOT(slotManButtonClicked()));
+	connect (pButtonEdit,    SIGNAL(clicked ()), this, SLOT(slotEditButtonClicked()));
 	connect (pButtonDefault, SIGNAL(clicked ()), this, SLOT(slotDefaultButtonClicked()));
 }
 
@@ -249,7 +285,7 @@ void DialogExecute::createStandardBlock (QWidget *pParent, QGridLayout *pParentL
 
 void DialogExecute::createTranscodeBlock (ExecuteInterface *pInterface, int t)
 {
-	int i, j, iYPos;
+        int i, j, iYPos, iDefaultComment;
 	QLabel		*pComment;
 	QComboBox	*pCommand;
 	QPushButton	*pButtonDefault;
@@ -270,10 +306,13 @@ void DialogExecute::createTranscodeBlock (ExecuteInterface *pInterface, int t)
 	pButtonDefault->setMaximumSize ( 25, 25 );
 	pButtonDefault->setText( tr( "d" ) );
 	pCommand->setEditable(FALSE);
+	iDefaultComment = pInterface->listDefaults[0];
+	if ( iDefaultComment >= (int)pInterface->listCommentList[0].count ( ) )
+	     iDefaultComment = 0;
 	for (i=0;i<(int)pInterface->listSplitAt.count ();i++)
-		pCommand->insertItem (pInterface->listCommandList[0][i]);
-	pComment->setText            (pInterface->commentList    [0]);
-	pCommand->setCurrentItem     (pInterface->listDefaults   [0]);
+		pCommand->insertItem ( pInterface->listCommandList[0][i] );
+	pComment->setText            ( pInterface->listCommentList[0][iDefaultComment] );
+	pCommand->setCurrentItem     ( pInterface->listDefaults   [0] );
 
 	pGroupBoxLayout->addMultiCellWidget ( pComment, iYPos, iYPos, 0, 1 );
 	iYPos ++;
@@ -281,14 +320,31 @@ void DialogExecute::createTranscodeBlock (ExecuteInterface *pInterface, int t)
 	pGroupBoxLayout->addWidget ( pButtonDefault, iYPos, 2 );
 	iYPos ++;
 
-	m_listTranscodeCombos.append     ( pCommand );
-	m_listCommandsWidget.append      ( pCommand );
-	m_listCommentsWidget.append      ( pComment );
-	m_listButtonWidgets.append       ( NULL     );
-	m_listButtonEdit.append          ( NULL     );
-	m_listButtonSetAsDefault.append  ( pButtonDefault );
-	m_listBlockID.append             ( pInterface->listBlockIDs[0] );
-	m_listBlockExecuteInterface.append(t);// this connects the ExecuteInterface with the generated Block
+	//////////////////////////////////////////////////////////////////////////////////////////////////////
+	//for (int x=0; x<pInterface->listCommandList.count ( ); x++ ) {
+	//  for (int y=0;y<pInterface->listCommandList[x].count ( ); y++ ) {
+	//    printf ( "Trans Command [%d][%d]=<%s>\n", x, y, pInterface->listCommandList[x][y].ascii ( ) );
+	//  }
+	//}
+	//for (int x=0; x<pInterface->listCommentList.count ( ); x++ ) {
+	//  for (int y=0;y<pInterface->listCommentList[x].count ( ); y++ ) {
+	//    printf ( "Trans Comment [%d][%d]=<%s>\n", x, y, pInterface->listCommentList[x][y].ascii ( ) );
+	//  }
+	//}
+	//////////////////////////////////////////////////////////////////////////////////////////////////////
+
+	GuiBlock *pGuiBlock               = new GuiBlock;
+	pGuiBlock->listComments           = pInterface->listCommentList[0];
+	pGuiBlock->pComboTranscode        = pCommand;
+	pGuiBlock->pComboCommands         = pCommand;
+	pGuiBlock->pLabelComment          = pComment;
+	pGuiBlock->pButtonMan             = NULL;
+	pGuiBlock->pButtonEdit            = NULL;
+	pGuiBlock->pButtonSetAsDefault    = pButtonDefault;
+	pGuiBlock->iBlockID               = pInterface->listBlockIDs[0];
+	pGuiBlock->iBlockExecuteInterface = t;// this connects the ExecuteInterface with the generated Block
+	m_listGui.append ( pGuiBlock );
+
 	connect (pCommand,       SIGNAL(activated (int)), this, SLOT(slotTranscodeSelectionChanged(int)));
 	connect (pButtonDefault, SIGNAL(clicked ()), this, SLOT(slotDefaultButtonClicked()));
 
@@ -318,7 +374,8 @@ void DialogExecute::createTranscodeBlock (ExecuteInterface *pInterface, int t)
 		// Hide everything but the default selection.
 		if (pInterface->listDefaults[0] != i)
 			pGroupBox->hide ();
-		m_listTranscodeFrames.append ( pGroupBox );
+		pGuiBlock->listTranscodeFrames.append ( pGroupBox );
+		//		m_listTranscodeFrames.append ( pGroupBox );
 	}
 }
 
@@ -384,51 +441,114 @@ void DialogExecute::resizeEvent (QResizeEvent *p)
 	slotTabChanged (m_pTabExpert);
 }
 
-void DialogExecute::slotTranscodeSelectionChanged (int iNewSelection)
+void DialogExecute::slotNormalSelectionChanged (int iNewSelection)
 {
-	uint t, i, iComboCount;
-	// Called when the user changes from e.g Transcode, to MEncoder ...
-	for (t=0;t<m_listTranscodeCombos.count();t++)	{
-		if (m_listTranscodeCombos[t]->hasFocus ())	{
-			// Okay every transcode block has the same amount of options 
-			// (currently only transcode and mencoder)
-			iComboCount = m_listTranscodeCombos[t]->count ();
-			for (i=0;i<iComboCount;i++)	{
-				if (iNewSelection == (int)i)
-					m_listTranscodeFrames[t*iComboCount+i]->show ();
-				else
-					m_listTranscodeFrames[t*iComboCount+i]->hide ();
-			}
-			slotTabChanged (m_pTabExpert);
-			return;
-		}
-	}
+  uint t;
+  GuiBlock *pGuiBlock;
+  // Called when the user changes from e.g Transcode, to MEncoder ...
+  for ( t=0; t<m_listGui.count ( ); t++ )  {
+    pGuiBlock = m_listGui[t];
+    if ( ( ! pGuiBlock ) || ( ! pGuiBlock->pComboCommands ) )
+      continue;
+    if ( pGuiBlock->pComboCommands->hasFocus ( ) )	{
+      if ( iNewSelection >= (int)pGuiBlock->listComments.count ( ) )
+	   iNewSelection = 0;
+      pGuiBlock->pLabelComment->setText ( pGuiBlock->listComments[iNewSelection] );
+      slotTabChanged (m_pTabExpert);
+      return;
+    }
+  }
 }
 
+void DialogExecute::slotTranscodeSelectionChanged (int iNewSelection)
+{
+  uint t, i, iComboCount;
+  QWidget *pFrame = NULL;
+  QComboBox *pCombo;
+  GuiBlock *pGuiBlock;
+  // Called when the user changes from e.g Transcode, to MEncoder ...
+  for ( t=0; t<m_listGui.count ( ); t++ )  {
+    pGuiBlock = m_listGui[t];
+    if ( ( ! pGuiBlock ) || ( ! pGuiBlock->pComboTranscode ) )
+      continue;
+    if ( pGuiBlock->pComboTranscode->hasFocus ( ) )	{
+      pCombo = pGuiBlock->pComboTranscode;
+      // Okay every transcode block has the same amount of options 
+      // (currently only transcode and mencoder)
+      iComboCount = pCombo->count ( );
+      for (i=0;i<iComboCount;i++)	{
+	if ( i < pGuiBlock->listTranscodeFrames.count ( ) ) {
+	  pFrame = pGuiBlock->listTranscodeFrames[i];
+	  if ( pFrame ) {
+	    if (iNewSelection == (int)i )
+	      pFrame->show ( );
+	    else
+	      pFrame->hide ( );
+	  }
+	}
+      }
+      if ( iNewSelection >= (int)pGuiBlock->listComments.count ( ) )
+	   iNewSelection = 0;
+      pGuiBlock->pLabelComment->setText ( pGuiBlock->listComments[iNewSelection] );
+      slotTabChanged (m_pTabExpert);
+      return;
+    }
+  }
+}
+/*
+void DialogExecute::slotTranscodeSelectionChanged (int iNewSelection)
+{
+  uint t, i, iComboCount;
+  QWidget *pFrame = NULL;
+  // Called when the user changes from e.g Transcode, to MEncoder ...
+  for (t=0;t<m_listTranscodeCombos.count();t++)	{
+    if (m_listTranscodeCombos[t]->hasFocus ())	{
+      // Okay every transcode block has the same amount of options 
+      // (currently only transcode and mencoder)
+      iComboCount = m_listTranscodeCombos[t]->count ();
+      for (i=0;i<iComboCount;i++)	{
+	if ( ( t*iComboCount+i ) < m_listTranscodeFrames.count () ) {
+	  pFrame = m_listTranscodeFrames[t*iComboCount+i];
+	  if ( pFrame ) {
+	    if (iNewSelection == (int)i )
+	      pFrame->show ( );
+	    else
+	      pFrame->hide ( );
+	  }
+	}
+      }
+      slotTabChanged (m_pTabExpert);
+      return;
+    }
+  }
+}
+*/
 void DialogExecute::slotTabChanged(QWidget *pTab)
 {
-	int iWidth, iViewWidth, iOffset;
-	uint t;
-	QPoint pos, globPos;
-
-	if (pTab == m_pTabExpert)	{
-		m_pScrollFrame->adjustSize();
-		iViewWidth = m_pScrollView->visibleWidth();
-		if (iViewWidth < 100)
-			iViewWidth = 200;
-		for (t=0;t<m_listCommandsWidget.count();t++)	{
-			iOffset = 0;
-			pos = m_listCommandsWidget[t]->pos();
-			globPos = m_listCommandsWidget[t]->mapTo(m_pScrollFrame, pos);
-			// If the this is not a SubSubFrame, then we can extend it by 11 (Layout margin)
-			if (m_listCommandsWidget[t]->parentWidget ()->parent () == m_pScrollFrame)
-				iOffset = 11;
-			iWidth = iViewWidth - 139 + iOffset - globPos.x();
-			if (iWidth < 100)
-				iWidth = 200;
-			m_listCommandsWidget[t]->setFixedWidth(iWidth);
-		}
-	}
+  int iWidth, iViewWidth, iOffset;
+  uint t;
+  QPoint pos, globPos;
+  GuiBlock *pGuiBlock;
+ 
+  if (pTab == m_pTabExpert)	{
+    m_pScrollFrame->adjustSize();
+    iViewWidth = m_pScrollView->visibleWidth();
+    if (iViewWidth < 100)
+      iViewWidth = 200;
+    for ( t=0; t<m_listGui.count(); t++ )	{
+      pGuiBlock = m_listGui[t];
+      iOffset = 0;
+      pos = pGuiBlock->pComboCommands->pos();
+      globPos = pGuiBlock->pComboCommands->mapTo ( m_pScrollFrame, pos );
+      // If the this is not a SubSubFrame, then we can extend it by 11 (Layout margin)
+      if ( pGuiBlock->pComboCommands->parentWidget ( )->parent ( ) == m_pScrollFrame )
+	iOffset = 11;
+      iWidth = iViewWidth - 139 + iOffset - globPos.x();
+      if (iWidth < 100)
+	iWidth = 200;
+      pGuiBlock->pComboCommands->setFixedWidth(iWidth);
+    }
+  }
 }
 
 void DialogExecute::slotCheckBlock(bool)
@@ -498,36 +618,39 @@ void DialogExecute::slotHelp ()
   raise ();
 }
 
-void DialogExecute::slotManButtonClicked()
+void DialogExecute::slotManButtonClicked ( )
 {
-	QStringList listOfCommandsUsed;
-	QWidget *pFromList;
-	QWidget *pButton = childAt (mapFromGlobal(QCursor::pos()));
-	if (!pButton)
-		return;
-	WId buttonID = pButton->winId();
-	for (uint t=0;t<m_listButtonWidgets.count();t++)	{
-		pFromList = m_listButtonWidgets[t];
-		if ( ! pFromList )
-			continue;
-		if (m_listButtonWidgets[t]->winId() == buttonID)	{
-			// Here we create the list of the commands in this commandString.
-			QString qsCommand = m_listCommandsWidget[t]->currentText();
-			QStringList partialCommandList = QStringList::split (";", qsCommand);
-			for (uint i=0;i<partialCommandList.count();i++)	{
-				QStringList partialCommandList2 = QStringList::split ("|", partialCommandList[i]);
-				for (uint j=0;j<partialCommandList2.count();j++)	{
-					QStringList argumentList =  QStringList::split (" ", partialCommandList2[j]);
-					// the first argument is always the command.
-					// but we don't want the cd command.
-					if (argumentList[0] != "cd")
-						listOfCommandsUsed.append(argumentList[0]);
-				}
-			}
-			createManPages (listOfCommandsUsed);
-			return;
-		}
+  QStringList listOfCommandsUsed;
+  QWidget    *pFromList;
+  QWidget    *pButton = childAt ( mapFromGlobal ( QCursor::pos ( ) ) );
+  GuiBlock *pGuiBlock;
+
+  if (!pButton)
+    return;
+  WId buttonID = pButton->winId();
+  for ( uint t=0; t<m_listGui.count ( ); t++ ) {
+    pGuiBlock = m_listGui[t];
+    pFromList = pGuiBlock->pButtonMan;
+    if ( ! pFromList )
+      continue;
+    if ( pGuiBlock->pButtonMan->winId ( ) == buttonID )	{
+      // Here we create the list of the commands in this commandString.
+      QString qsCommand = pGuiBlock->pComboCommands->currentText ( );
+      QStringList partialCommandList = QStringList::split (";", qsCommand);
+      for (uint i=0;i<partialCommandList.count();i++)	{
+	QStringList partialCommandList2 = QStringList::split ("|", partialCommandList[i]);
+	for (uint j=0;j<partialCommandList2.count();j++)	{
+	  QStringList argumentList =  QStringList::split (" ", partialCommandList2[j]);
+	  // the first argument is always the command.
+	  // but we don't want the cd command.
+	  if (argumentList[0] != "cd")
+	    listOfCommandsUsed.append(argumentList[0]);
 	}
+      }
+      createManPages (listOfCommandsUsed);
+      return;
+    }
+  }
 }
 
 void DialogExecute::slotEditButtonClicked()
@@ -536,35 +659,37 @@ void DialogExecute::slotEditButtonClicked()
   QStringList listOfCommandsUsed;
   QWidget *pFromList;
   int iWhichKeyset = Keyword::Keys;
+  GuiBlock *pGuiBlock;
   // In order to get the button we clicked we use the Cursor position ...
   QWidget *pButton = childAt ( mapFromGlobal ( QCursor::pos ( ) ) );
   if ( ! pButton )
     return;
   
   WId buttonID = pButton->winId ( );
-  for ( t=0;t<m_listButtonEdit.count ( );t++ )	{
-    pFromList = m_listButtonEdit[t];
+  for ( t=0; t<m_listGui.count  ( ); t++ )  {
+    pGuiBlock = m_listGui[t];
+    pFromList = pGuiBlock->pButtonEdit;
     if (!pFromList)
       continue;
     if (pFromList->winId() == buttonID)	{
       // Here we open the CommandEditDialog ...
       if (m_pInitObject)	{
-	QDVDAuthorInit::MenuBlock::Block *pBlock = m_pInitObject->getBlock (m_listBlockID[t], &iWhichKeyset );
+	QDVDAuthorInit::MenuBlock::Block *pBlock = m_pInitObject->getBlock (pGuiBlock->iBlockID, &iWhichKeyset );
 	if (pBlock)	{
 	  // Here we get the index to the appropriate ExecuteInterface for the given Block
-	  int iInterface = m_listBlockExecuteInterface[t];
+	  int iInterface = pGuiBlock->iBlockExecuteInterface;
 	  Keyword *pKeyword = m_pInitObject->getKeyword ( );
 	  DialogCommandEditor *pEditor = new DialogCommandEditor (this);
-	  pEditor->initMe (pBlock, m_listCommandsWidget[t]->currentItem(), pKeyword->getKeys ( iWhichKeyset ), m_listExecuteInterface[iInterface]->listKeywords.count() );
-	  if (pEditor->exec () != QDialog::Rejected) {
+	  pEditor->initMe (pBlock, pGuiBlock->pComboCommands->currentItem ( ), pKeyword->getKeys ( iWhichKeyset ), m_listExecuteInterface[iInterface]->listKeywords.count ( ) );
+	  if ( pEditor->exec ( ) != QDialog::Rejected ) {
 	    // Here we set the command line to the modified strings. 
 	    // and then we set the keywords for the found ExecuteInterface - object.
 	    pKeyword->setKeywords( iWhichKeyset, m_listExecuteInterface[iInterface]->listKeywords );
 	    // and finally we generate the command / header with the correct keywords ...
-	    m_listCommandsWidget[t]->clear ();
+	    pGuiBlock->pComboCommands->clear ( );
 	    for (i=0; i<pBlock->listCommands.count ( );
-		 m_listCommandsWidget[t]->insertItem( pKeyword->resolvString( iWhichKeyset, pBlock->listCommands[i++] ) ) );
-	    m_listCommentsWidget[t]->setText ( pKeyword->resolvString( iWhichKeyset, pBlock->listComments[0] ) );
+		 pGuiBlock->pComboCommands->insertItem( pKeyword->resolvString( iWhichKeyset, pBlock->listCommands[i++] ) ) );
+	    pGuiBlock->pLabelComment->setText ( pKeyword->resolvString( iWhichKeyset, pBlock->listComments[0] ) );
 	    m_pInitObject->setToolsPaths ( m_listToolsPaths );
 	    m_pInitObject->saveIniFile   ( );
 	    // this is to re-set the ToolsPaths information (keep it in here)
@@ -580,22 +705,24 @@ void DialogExecute::slotEditButtonClicked()
 
 void DialogExecute::slotDefaultButtonClicked()
 {
-	QWidget *pButton = childAt (mapFromGlobal(QCursor::pos()));
-	if (!pButton)
-		return;
-	WId buttonID = pButton->winId();
-	for (uint t=0;t<m_listButtonSetAsDefault.count();t++)	{
-		if (m_listButtonSetAsDefault[t]->winId() == buttonID)	{
-			if (m_pInitObject)	{
-				m_pInitObject->setDefault (m_listBlockID[t], m_listCommandsWidget[t]->currentItem());
-				m_pInitObject->setToolsPaths ( m_listToolsPaths );
-				m_pInitObject->saveIniFile();
-				// this is to re-set the ToolsPaths information (keep it in here)
-				m_pInitObject->getToolsPaths ( );
-			}
-			return;
-		}
-	}
+  QWidget *pButton = childAt (mapFromGlobal(QCursor::pos()));
+  GuiBlock *pGuiBlock;
+  if (!pButton)
+    return;
+  WId buttonID = pButton->winId();
+  for ( uint t=0; t<m_listGui.count ( ); t++ )  {
+    pGuiBlock = m_listGui[t];
+    if ( pGuiBlock->pButtonSetAsDefault->winId() == buttonID)	{
+      if (m_pInitObject)	{
+	m_pInitObject->setDefault ( pGuiBlock->iBlockID, pGuiBlock->pComboCommands->currentItem ( ) );
+	m_pInitObject->setToolsPaths ( m_listToolsPaths );
+	m_pInitObject->saveIniFile();
+	// this is to re-set the ToolsPaths information (keep it in here)
+	m_pInitObject->getToolsPaths ( );
+      }
+      return;
+    }
+  }
 }
 
 void DialogExecute::slotRenderMenu (QString qsMenuName)
@@ -620,61 +747,63 @@ void DialogExecute::createManPages(QStringList &listOfCommandsUsed)
 
 void DialogExecute::slotExport()
 {
-        uint t, iCounter = 0;
-	int  i;
-	// This function creates a script which the user can then execute ...
-	QString fileName = QFileDialog::getSaveFileName("./", tr("Shell file (*.sh)"), this,tr( "Save file dialog"),tr( "Save File As ..."));
-	if (fileName.isNull ())
-		return;
+  uint t, iCounter = 0;
+  int  i;
+  // This function creates a script which the user can then execute ...
+  QString fileName = QFileDialog::getSaveFileName("./", tr("Shell file (*.sh)"), this,tr( "Save file dialog"),tr( "Save File As ..."));
+  GuiBlock *pGuiBlock;
+  if (fileName.isNull ())
+    return;
 	
-	QFileInfo fileInfo(fileName);
-	if (fileInfo.extension(FALSE).isEmpty())
-		fileName += QString (".sh");
-	
-	QFile shellFile(fileName);
-	QString qsComment;
-	if ( shellFile.open( IO_WriteOnly ) ) {
-		QTextStream stream( &shellFile );
-		stream << Global::qsBashString;
-		stream << "run=0\n";
-		stream << "if [ $# -eq 0 ];\n";
-		stream << "then\n";
-		stream << "        run=1\n";
-		stream << "fi;\n\n";
-		stream << "while [ $# -gt 0 ] || [ $run -eq 1 ]\n";
-		stream << "do\n\n";
-
-		for (t=0;t<m_listCommandsWidget.count();t++)	{
-			// First we check if the user wants this command to get executed after all ...
-			if (m_listCommandsWidget[t]->isVisible ())	{
-			  stream << "if [ 1 -eq $run ] || [ " << ++iCounter << " -eq $1 ];\n";
-			  stream << "then\n";
-			  // Okay to also output the comments ...
-			  qsComment = stripTags(m_listCommentsWidget[t]->text());
-			  stream << "# " << qsComment + "\n";
-			  stream << "#############################################################################\n";
-			  // we should offer all options as comments and the current one as the real deal ...
-			  for (i=0;i<m_listCommandsWidget[t]->count();i++)	{
-			    if (i != m_listCommandsWidget[t]->currentItem())	{
-			      stream << "# Option " << i << " : \n";
-			      stream << "# " <<  getToolsPath(m_listCommandsWidget[t]->text(i)) + "\n";
-			    }
-			  }
-			  // And here we write the current selected Option ...
-			  if ( m_listCommandsWidget[t]->currentText().find ( "#=-" ) == 0 )  // we should add this to avoid an error message for this script.
-			    stream << "echo \"" << m_listCommandsWidget[t]->currentText() << "\"\n";
-			  else
-			    stream << getToolsPath(m_listCommandsWidget[t]->currentText()) + "\n";
-			  stream << "fi;\n\n";
-			}
-		}
-		stream << "shift\n";
-		stream << "run=0\n";
-		stream << "done\n\n";
-		shellFile.close();
-		chmod ((const char *)fileName, S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH);
-		emit (signalGenerateMasks ());
+  QFileInfo fileInfo(fileName);
+  if (fileInfo.extension(FALSE).isEmpty())
+    fileName += QString (".sh");
+  
+  QFile shellFile(fileName);
+  QString qsComment;
+  if ( shellFile.open( IO_WriteOnly ) ) {
+    QTextStream stream( &shellFile );
+    stream << Global::qsBashString;
+    stream << "run=0\n";
+    stream << "if [ $# -eq 0 ];\n";
+    stream << "then\n";
+    stream << "        run=1\n";
+    stream << "fi;\n\n";
+    stream << "while [ $# -gt 0 ] || [ $run -eq 1 ]\n";
+    stream << "do\n\n";
+    
+    for (t=0;t<m_listGui.count();t++)	{
+      pGuiBlock = m_listGui[t];
+      // First we check if the user wants this command to get executed after all ...
+      if ( pGuiBlock->pComboCommands->isVisible ( ) )  {
+	stream << "if [ 1 -eq $run ] || [ " << ++iCounter << " -eq $1 ];\n";
+	stream << "then\n";
+	// Okay to also output the comments ...
+	qsComment = stripTags( pGuiBlock->pLabelComment->text());
+	stream << "# " << qsComment + "\n";
+	stream << "#############################################################################\n";
+	// we should offer all options as comments and the current one as the real deal ...
+	for (i=0;i< pGuiBlock->pComboCommands->count ( );i++)	{
+	  if (i != pGuiBlock->pComboCommands->currentItem ( ) )	{
+	    stream << "# Option " << i << " : \n";
+	    stream << "# " <<  getToolsPath( pGuiBlock->pComboCommands->text ( i ) ) + "\n";
+	  }
 	}
+	// And here we write the current selected Option ...
+	if ( pGuiBlock->pComboCommands->currentText ( ).find ( "#=-" ) == 0 )  // we should add this to avoid an error message for this script.
+	  stream << "echo \"" << pGuiBlock->pComboCommands->currentText ( ) << "\"\n";
+	else
+	  stream << getToolsPath( pGuiBlock->pComboCommands->currentText ( ) ) + "\n";
+	stream << "fi;\n\n";
+      }
+    }
+    stream << "shift\n";
+    stream << "run=0\n";
+    stream << "done\n\n";
+    shellFile.close();
+    chmod ((const char *)fileName, S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH);
+    emit (signalGenerateMasks ());
+  }
 }
 
 QString DialogExecute::stripTags(QString qsInput)
@@ -690,22 +819,24 @@ QString DialogExecute::stripTags(QString qsInput)
 
 void DialogExecute::slotOkay()
 {
-	uint t;
-	QStringList listCommands;
-	// first let us create the masks ...
-	emit (signalGenerateMasks ());
-	for (t=0;t<m_listCommandsWidget.count();t++)	{
-		if (m_listCommandsWidget[t]->isVisible())
-			listCommands.append(getToolsPath(m_listCommandsWidget[t]->currentText()));
-	}
-	m_doSomething.system(listCommands);
+  uint t;
+  QStringList listCommands;
+  GuiBlock *pGuiBlock;
+  // first let us create the masks ...
+  emit ( signalGenerateMasks   ( ) );
+  for ( t=0; t<m_listGui.count ( ); t++ )	{
+    pGuiBlock = m_listGui[t];
+    if ( pGuiBlock->pComboCommands->isVisible())
+      listCommands.append ( getToolsPath ( pGuiBlock->pComboCommands->currentText ( ) ) );
+  }
+  m_doSomething.system ( listCommands );
+  
+  hide ();
 
-	hide ();
-
-	// for a blocking execution one has to start a timer, which checks m_doSomthing.isRunning()
-	// And calls accept () only after all commands have been executed.
-	// Also one needs to tak care of the user closing the execution-output-dialog.
-//	accept();
+  // for a blocking execution one has to start a timer, which checks m_doSomthing.isRunning()
+  // And calls accept () only after all commands have been executed.
+  // Also one needs to tak care of the user closing the execution-output-dialog.
+  //	accept();
 }
 
 QString DialogExecute::getToolsPath(QString qsCommandLine)
