@@ -5,10 +5,17 @@
 ** Qt Designer which will update this file, preserving your code. Create an
 ** init() function in place of a constructor, and a destroy() function in
 ** place of a destructor.
+**
+**   Created : 
+**        by : Varol Okan 
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 *****************************************************************************/
 
 #include <qpixmap.h>
 
+#include "utils.h"
 #include "global.h"
 #include "qimagehelper.h"
 
@@ -191,7 +198,7 @@ void CResizeDialog::slotOk(void)
 {
 	int iWidth, iHeight;
 	bool  bOk = true;
-
+	Utils theUtils;
 	iWidth = m_pEditWidth->text().toInt(&bOk);
 	if (!bOk)	{
 		iWidth = 720;
@@ -208,6 +215,7 @@ void CResizeDialog::slotOk(void)
 	else if (m_pRadioStretch3->isOn())
 		m_iStretchType = 2;
 
+	m_iFormat = theUtils.getFormat ( iWidth, iHeight );
 	preview(iWidth, iHeight, getResizeAlgorithm());
 	accept();
 }
