@@ -1,8 +1,10 @@
 /****************************************************************************
 ** DialogShadow - class
 **
-** Created: Thu Aug 3 22:05:18 2006
-**      by: Varol Okan Using XEmacs
+**   Created : Thu Aug 3 22:05:18 2006
+**        by : Varol Okan Using XEmacs
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ****************************************************************************/
 
@@ -28,8 +30,9 @@ public:
   void initMe ( MenuObject *, QPixmap * );
 
 protected:
-  void drawShadow ( );
-  void refresh    ( );
+  void drawShadow   ( );
+  void refresh      ( );
+  int getDialogType ( );
 
 protected slots:
   virtual void accept               ( );
@@ -39,11 +42,23 @@ protected slots:
   virtual void slotTransparency ( int );
   virtual void slotDistance     ( int );
   virtual void slotSunAngle     ( int );
+  virtual void slotStyle        ( int );
   virtual void slotBlur         ( int );
+  virtual void slotShearX       ( int );
+  virtual void slotShearY       ( int );
+  virtual void slotScaleX       ( int );
+  virtual void slotScaleY       ( int );
+  virtual void slotCutOff       ( int );
+  virtual void slotCutOffRadius ( int );
+  virtual void slotColorFade    ( int );
+  virtual void slotTransparency     ( );
+  virtual void slotCutOff           ( );
+  virtual void slotCutOffRadius     ( );
 
 private:
   void keepStaticVariables ( );
   void setStaticVariables  ( );
+  void displayAdvanced     ( bool );
 
 private:
   QPixmap      *m_pBackground;
@@ -53,6 +68,11 @@ private:
   QLabel       *m_pPreview;
   QScrollView  *m_pScrollView;
 
+  // some playfield varialbles for the animation of the advanced part.
+  int m_iAdvancedWidth; // stores the width of the m_pFrameMirror for the animation effect
+
+  bool m_bStoredActiveState; // the object is to be drawn in normal state.
+
   // static vars to keep the current values for the shadow
   // this way the user does not always have to start from square one.
   static int    m_keepBlurRadius;
@@ -60,6 +80,16 @@ private:
   static float  m_keepDistance;
   static float  m_keepSunAngle;
   static QColor m_keepColor;
+
+  static float  m_keepShearX;
+  static float  m_keepShearY;
+  static float  m_keepScaleX;
+  static float  m_keepScaleY;
+  static float  m_keepCutOff;
+  static float  m_keepCutOffRadius;
+  static float  m_keepColorFade;
+  static QColor m_keepTargetColor;
+
 };
 
 #endif // DIALOGSHADOW_H
