@@ -2,6 +2,11 @@
 /****************************************************************************
 ** exportsrt.cpp
 **
+**   Created : 
+**        by : Varol Okan 
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ** This file holds the implementation of the export filter for the srt 
 ** subtitles file.
 *****************************************************************************/
@@ -38,17 +43,22 @@ bool Srt::writeFile ( Subtitles *pSubtitles, QString &fileName )
 {
   uint t;
   // Assign the file
+  QString qsTimeStart, qsTimeStop;
   Subtitles::entry *pEntry;
   QFile projectFile ( fileName );
 
-  if ( ! projectFile.open ( IO_Raw | IO_ReadWrite ) )
+  if ( ! projectFile.open ( IO_ReadWrite ) )
     return false;
   
   QTextStream srtStream( &projectFile );
-  for ( t=0;t<pSubtitles->listOfSubtitles.count ();t++) {
-    pEntry = pSubtitles->listOfSubtitles[t];
-    srtStream << pEntry->iIndex << "\n";
-    srtStream << pEntry->qsTimeStart << " --> " << pEntry->qsTimeStop << "\n";
+  for ( t=0;t<pSubtitles->m_listOfSubtitles.count ();t++) {
+    pEntry = pSubtitles->m_listOfSubtitles[t];
+	qsTimeStart = pEntry->qsTimeStart;
+	qsTimeStart.replace ( ".", "," );
+	qsTimeStop  = pEntry->qsTimeStop;
+	qsTimeStop.replace  ( ".", "," ); 
+	srtStream << pEntry->iIndex << "\n";
+    srtStream << qsTimeStart << " --> " << qsTimeStop << "\n";
     srtStream << pEntry->qsText << "\n\n";
   }
   
