@@ -1,11 +1,30 @@
+/****************************************************************************
+** Global variables
+**
+**   Created : Dec 2003
+**        by : Varol Okan using the kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
+** This class collects all possible information about
+** the current set stream.
+**
+****************************************************************************/
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
 #include <qstring.h>
 #include <qeventloop.h>
+#include <qvaluelist.h>
 // Include the logging facilities ...
+#include "utils.h"
 #include "log.h"
 
+// Forward declartion of the Thumbs cache class
+namespace Cache {
+   class Thumbs;
+};
+
 #define DEBUG_INFO 1
 
 // Here we define all external tools neccesary
@@ -15,6 +34,7 @@
 		{"dvdauthor",     "DVDAuthor",      "Mandatory !\n\nThis is the main application needed to create a Movie DVD.\nhttp://dvdauthor.sf.net"}, \
 		{"spumux",        "Spumux",         "Mandatory !\n\nThis program is part of the dvdauthor package.\nhttp://dvdauthor.sf.net"}, \
 		{"mplex",         "MPlex",          "Mandatory !\n\nThis program is part of the dvdauthor package.\nhttp://dvdauthor.sf.net"}, \
+		{"dv2sub",        "DV to Sub",      "Optional. Important.\n\nThis program will generate subtitles from the meta information in a DV stream.\nhttp://dv2sub.sf.net"}, \
 		{"arecord",       "ARecord",        "Optional.\n\nALSA sound utility. There are other utilities you can use instead."}, \
 		{"movie-to-dvd",  "VideoTrans",     "Optional. Important.\n\nYou can also use MEncoder, or transcode.\nThis utility uses MPlayer to convert movies into the correct format (See also man pages).\nhttp://videotrans.sf.net"}, \
 		{"transcode",     "Transcode",      "Optional. Important.\n\nYou can also use MEncoder.\nThis utility converts movies into the correct format (See also man pages).\nhttp://www.transcoding.org"}, \
@@ -38,8 +58,8 @@
 		{"convert",       "Convert",        "Optional. Important.\n\nThis utility is used with dvd-slideshow to create the mpeg2 video stream.\nhttp://imagemagick.sf.net."}, \
 		{"growisofs",     "Grow ISO FS",    "Optional.\n\nThis utility is used to burn the video DVD onto the DVD."}, \
 		{"dvd+rw-format", "DVD+RW Format",  "Optional.\n\nThis utility is used to burn the video DVD onto a RW+DVD."}, \
-		{"mkisofs",       "Make ISO FS",    "Optional.\n\nThis utility is used to create a iso image of the final DVD (on the harddrive) to be burned with your favourite burning progrfam."}, \
-		{"dvdrecord",     "DVD Record",     "Optional.\n\nThis utility is used to recodre the video DVD onto the DVD."}
+		{"mkisofs",       "Make ISO FS",    "Optional.\n\nThis utility is used to create a iso image of the final DVD (on the harddrive) to be burned with your favourite burning program."}, \
+		{"dvdrecord",     "DVD Record",     "Optional.\n\nRecords the final DVD structure onto the DVD media."}
 
 #define STRING_SEPARATOR "+-+"
 
@@ -70,7 +90,7 @@
 #define SELECTED_NAME		"selected.png"
 #define HIGHLIGHTED_NAME	"highlighted.png"
 
-// The max colors a mask (button) can have. Either 4 or 16, not sure.
+// The max colors a mask (button) can have.
 #define MAX_MASK_COLORS 4
 
 // Here we define the color which is to be interpreted as transparent (only used as a type of flag)
@@ -78,8 +98,15 @@
 
 // These are the standard colors for the SELECTED, and HIGHLIGHTED layer.
 // Note: max of 4 colors are allowed, so colorspace is sparse.
-#define START_HIGHLIGHTED_COLOR  250,150,50
-#define START_SELECTED_COLOR     255, 20, 20
+#define START_HIGHLIGHTED_COLOR  250,150,  50
+#define START_SELECTED_COLOR     255, 20,  20
+
+// These are the initial colors for the subtitles.
+// Note: the third color ill be interpolated between BG and FG color.
+//       the fourth color if transparent
+//#define START_SUBTITLEFG_COLOR   233, 240, 24
+#define START_SUBTITLEFG_COLOR   200, 200,  0
+#define START_SUBTITLEBG_COLOR     0,   0,  0
 
 // This color is applied to the background, thus it can be different unless the user 
 // decides to put it onto a Selected / highlighted layer.
@@ -94,18 +121,23 @@
 #define COLOR_SLIDE_FILES_OK  210, 130, 170
 #define COLOR_SLIDE_FILES_BAD 225, 140, 180
 #define COLOR_MOVIE_TRANSCODE 170,   0, 255
+#define COLOR_AUDIO_TRANSCODE 150,  20, 235
 
 // PI is always good to have  3.141592653589793238462643383279502884197169399375105820974944592
 #ifndef PI
 #define PI 3.1415926536
 #endif
 
+class MenuObject;
+class QDVDAuthor;
+
 class Global
 {
 public:
 	 Global ();
 	~Global ();
 	static Log    *pLogObject;
+	static QDVDAuthor *pApp;
 	static QString qsBashString;
 	static QString qsProjectFileName;
 	static QString qsProjectName;
@@ -113,10 +145,17 @@ public:
 	static QString qsProjectPath;
 	static QString qsCurrentPath;
 	static QString qsExternalPlayer;
+	static QString qsLanguage;
+	static QString qsDefaultLanguage; // en
+	static QString qsDefaultFormat;   // PAL or NTSC
 	static uint    iMaxRunningThreads;
 	static int     iDeleteTempOlderThan;
 	static int     iChildThreadPriority;
-	static QEventLoop eventLoop;
+	static QEventLoop  eventLoop;
+	static MenuObject *pCopyObject;
+	// Here we store the path to the different tools required.
+	static QValueList<Utils::toolsPaths *> listToolsPaths;
+	static Cache::Thumbs *pThumbsCache;
 };
 
 #endif // GLOBAL_H
