@@ -1,6 +1,11 @@
 /****************************************************************************
 ** listviewmedia - class
 **
+**   Created :
+**        by : Varol Okan 
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
+**
 ** This file re-implements the QListView class
 ** and handles the drag event by re-implementing
 ** the dragObject function.
@@ -175,7 +180,7 @@ void ListViewMedia::handleSubtitleTracks ( SourceFileEntry *pEntry )
 	    delete pSubtitle;
 	    pInfo->arraySubtitles [ i ] = NULL;
 	  }
-	  else { // And finally we can cfreate the new entry and shift around ...
+	  else { // And finally we can create the new entry and shift around ...
 	    pEntry->arraySubtitleEntries [ j ].m_iSubtitleNumber = j;
 	    pEntry->arraySubtitleEntries [ j ].m_qsIso639 = pSubtitle->m_qsIso639;
 	    pSubtitle->m_iSubtitleNumber = j;
@@ -313,7 +318,6 @@ QDragObject *ListViewMedia::dragObject()
 	return pDragObject;
 }
 
-
 void ListViewMedia::slotItemClicked (QListViewItem *pItem, const QPoint &thePoint, int)
 {
 	if (!pItem)
