@@ -1,18 +1,20 @@
 /****************************************************************************
 ** Modifiers / ImageManipulator class implementation.
 **
-** Created: ?
-**      by: Varol Okan using Kate
+**   Created : ?
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **
 **
 **
 ****************************************************************************/
 
-#include <qlistview.h>
-
+#include "structuretoolbar.h"
 #include "modifiers.h"
 #include "xml_dvd.h"
+#include "rgba.h"
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
@@ -21,14 +23,19 @@
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 Modifiers::Modifiers() 
 { 
-	fRotate = fShearX = fShearY = fTransparency = 0.0; 
-	fZoom = fScaleX = fScaleY = 1.0; 
-	iStartFrame = iStopFrame = 0;
+  fRotate = fShearX = fShearY = fTransparency = 0.0; 
+  fZoom   = fScaleX = fScaleY = 1.0; 
+  iStartFrame       =  iStopFrame  =  -1;
+  m_pStructureItem  = NULL;
 }
 
 Modifiers::~Modifiers() 
 {
-
+  // Since the Modifier is part of a MenuObject AND the MenuObject deletes its own StructureItem,
+  // This StructureItem is already destroyed.
+  //  if ( m_pStructureItem )
+  //    delete m_pStructureItem;
+  //  m_pStructureItem = NULL;
 }
 
 Modifiers& Modifiers::operator = (Modifiers &other)
@@ -137,6 +144,42 @@ bool Modifiers::readProjectFile (QDomNode &theNode)
   return true;
 }
 
+StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, StructureItem *pPreviousItem )
+{
+  // And finally we create the modifiers info ...
+  if ( !( (fRotate == 0.0) && (fShearX == 0.0) && (fShearY == 0.0) &&
+	  (fZoom   == 1.0) && (fScaleX == 1.0) && (fScaleY == 1.0) ) )  {
+    // First we get the translatable strings :
+    StructureItem *pTemp;
+    MenuObject *pMenuObject = pParentItem->getMenuObject ( );
+    QString qsModifiers = QObject::tr ( "Modifiers"    );
+    QString qsShear     = QObject::tr ( "Shear (x, y)" );
+    QString qsZoom      = QObject::tr ( "Zoom"         );
+    QString qsRotate    = QObject::tr ( "Rotate"       );
+
+    if ( ! m_pStructureItem )  {
+      m_pStructureItem = new StructureItem ( pMenuObject, pParentItem, pPreviousItem, qsModifiers, NULL );
+      m_pStructureItem->setExpandable ( TRUE );
+    }
+
+    // Comming here we are guaranteed to have a StructureItem - object.
+    QString qsArgs = QObject::tr ( "%1 deg" ).arg ( fRotate );
+    pTemp  = m_pStructureItem->setSibling ( pMenuObject, NULL, qsRotate, qsArgs );
+
+    qsArgs = QString ( "%1 <%2x%3>" ).arg ( fZoom ).arg ( fScaleX ).arg ( fScaleY );
+    pTemp  = m_pStructureItem->setSibling ( pMenuObject, pTemp, qsZoom,  qsArgs );
+    
+    qsArgs = QString ( "%1, %2" ).arg ( fShearX ).arg ( fShearY );
+    pTemp  = m_pStructureItem->setSibling ( pMenuObject, pTemp, qsShear, qsArgs );
+  }
+  else if ( m_pStructureItem ) {
+    delete  m_pStructureItem;
+    m_pStructureItem = NULL;
+  }
+
+  return m_pStructureItem;
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 //
 // ImageManipulator class
@@ -148,23 +191,29 @@ ImageManipulator::ImageManipulator ()
 
 	backgroundFileName = QString ("");
 	bShowBackground = false;
-	fStartX = 0.0;
-	fStartY = 0.0;
+	fKenBurnsX1 = -1.0f;
+	fKenBurnsY1 = -1.0f;
+	fKenBurnsX2 = -1.0f;
+	fKenBurnsY2 = -1.0f;
+	fStartX     =  0.0f;
+	fStartY     =  0.0f;
 	iXRes = 720;
 	iYRes = 480;
 	iTransformationMode = 0;
-	fAspectRatio = 4.0/3.0;
-	fShearX = 0.0;
-	fShearY = 0.0;
-	fZoom   = 1.0;
-	fRotate = 0.0;
-	fRed    = 1.0;
-	fGreen  = 1.0;
-	fBlue   = 1.0;
-	fBrightness   = 0.0;
-	fTransparency = 0.0;	// Opaque in the beginning ...
-	iStartFrame   = 0;
-	iStopFrame    = 0;
+	fAspectRatio = 4.0f/3.0f;
+	fShearX = 0.0f;
+	fShearY = 0.0f;
+	fZoom   = 1.0f;
+	fScaleX = 1.0f;
+	fScaleY = 1.0f;
+	fRotate = 0.0f;
+	fRed    = 1.0f;
+	fGreen  = 1.0f;
+	fBlue   = 1.0f;
+	fBrightness   = 0.0f;
+	fTransparency = 0.0f;	// Opaque in the beginning ...
+	iStartFrame   =   -1;
+	iStopFrame    =   -1;
 }
 
 ImageManipulator::~ImageManipulator()
@@ -199,6 +248,22 @@ bool ImageManipulator::readProjectFile (QDomNode &theNode)
 	if (!attribute.isNull())
 		fStartY = attribute.value().toFloat();
 
+	attribute = manElement.attributeNode ( MANIPULATOR_KENBURNS_X1 );
+	if (!attribute.isNull())
+		fKenBurnsX1 = attribute.value().toFloat();
+
+	attribute = manElement.attributeNode ( MANIPULATOR_KENBURNS_Y1 );
+	if (!attribute.isNull())
+		fKenBurnsY1 = attribute.value().toFloat();
+
+	attribute = manElement.attributeNode ( MANIPULATOR_KENBURNS_X2 );
+	if (!attribute.isNull())
+		fKenBurnsX2 = attribute.value().toFloat();
+
+	attribute = manElement.attributeNode ( MANIPULATOR_KENBURNS_Y2 );
+	if (!attribute.isNull())
+		fKenBurnsY2 = attribute.value().toFloat();
+
 	attribute = manElement.attributeNode ( MANIPULATOR_XRES );
 	if (!attribute.isNull())
 		iXRes = attribute.value().toInt();
@@ -232,10 +297,18 @@ bool ImageManipulator::readProjectFile (QDomNode &theNode)
 		fBrightness = attribute.value().toFloat();
 
 	// to get some sanity in backwards compatibility
-	if (fStartX > 1.0)
-	  fStartX = 0.0;
-	if (fStartY > 1.0)
-	  fStartY = 0.0;
+	if ( fStartX >  1.0 )
+	     fStartX =  0.0;
+	if ( fStartY >  1.0 )
+	     fStartY =  0.0;
+	if ( fKenBurnsX1 >  1.0 )
+	     fKenBurnsX1 = -1.0;
+	if ( fKenBurnsY1 >  1.0 )
+	     fKenBurnsY1 = -1.0;
+	if ( fKenBurnsX2 >  1.0 )
+	     fKenBurnsX2 = -1.0;
+	if ( fKenBurnsY2 >  1.0 )
+	     fKenBurnsY2 = -1.0;
 
 	for (uint t=0;t<listColorKeys.count();t++)
 		delete listColorKeys[t];
@@ -253,19 +326,19 @@ bool ImageManipulator::readProjectFile (QDomNode &theNode)
 		  Modifiers::readProjectFile ( manipulatorNodes );
 		}
 		if (tagName == MANIPULATOR_COLOR_KEY)	{
-			QColor theColor;
+			Rgba  theColor;
 			float fDelta = 0.0f;
 			colorKeying *pColorKey;
 			attribute = theElement.attributeNode ( MANIPULATOR_COLOR );
 			if (!attribute.isNull())
-				theColor.setNamedColor ( attribute.value() );
+				theColor.fromString ( attribute.value ( ) );
 
 			attribute = theElement.attributeNode ( MANIPULATOR_DELTA );
 			if (!attribute.isNull())
 				fDelta = attribute.value().toFloat();
 
-			pColorKey = new colorKeying ( theColor.rgb(), fDelta);
-			listColorKeys.append (pColorKey);
+			pColorKey = new colorKeying ( theColor.rgb ( ), fDelta);
+			listColorKeys.append ( pColorKey );
 		}
 		manipulatorNodes = manipulatorNodes.nextSibling();
 	}
@@ -280,6 +353,10 @@ bool ImageManipulator::isUnchanged ()
       ( bShowBackground     != initialValues.bShowBackground)     ||
       ( fStartX             != initialValues.fStartX)             ||
       ( fStartY             != initialValues.fStartY)             ||
+      ( fKenBurnsX1         != initialValues.fKenBurnsX1)         ||
+      ( fKenBurnsY1         != initialValues.fKenBurnsY1)         ||
+      ( fKenBurnsX2         != initialValues.fKenBurnsX2)         ||
+      ( fKenBurnsY2         != initialValues.fKenBurnsY2)         ||
       ( iXRes               != initialValues.iXRes)               ||
       ( iYRes               != initialValues.iYRes)               ||
       ( iTransformationMode != initialValues.iTransformationMode) ||
@@ -310,6 +387,14 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
       manipulatorNode.setAttribute( MANIPULATOR_STARTX, QString ("%1").arg(fStartX) );
     if (fStartY != initialValues.fStartY)
       manipulatorNode.setAttribute( MANIPULATOR_STARTY, QString ("%1").arg(fStartY) );
+    if (fKenBurnsX1 != initialValues.fKenBurnsX1)
+      manipulatorNode.setAttribute( MANIPULATOR_KENBURNS_X1, QString ("%1").arg(fKenBurnsX1) );
+    if (fKenBurnsY1 != initialValues.fKenBurnsY1)
+      manipulatorNode.setAttribute( MANIPULATOR_KENBURNS_Y1, QString ("%1").arg(fKenBurnsY1) );
+    if (fKenBurnsX2 != initialValues.fKenBurnsX2)
+      manipulatorNode.setAttribute( MANIPULATOR_KENBURNS_X2, QString ("%1").arg(fKenBurnsX2) );
+    if (fKenBurnsY2 != initialValues.fKenBurnsY2)
+      manipulatorNode.setAttribute( MANIPULATOR_KENBURNS_Y2, QString ("%1").arg(fKenBurnsY2) );
     if (iXRes != initialValues.iXRes)
       manipulatorNode.setAttribute( MANIPULATOR_XRES, QString ("%1").arg(iXRes) );
     if (iYRes != initialValues.iYRes)
@@ -327,13 +412,12 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
     if (fBrightness != initialValues.fBrightness)
       manipulatorNode.setAttribute( MANIPULATOR_BRIGHTNESS, QString ("%1").arg(fBrightness) );
     for (uint t=0;t<listColorKeys.count ();t++)	{
-      QColor theColor;
       QDomElement colorKeyNode = xmlDoc.createElement ( MANIPULATOR_COLOR_KEY );
-      if (listColorKeys[t]->fDeltaColor != 0.0)
-	colorKeyNode.setAttribute ( MANIPULATOR_DELTA, QString ("%1").arg (listColorKeys[t]->fDeltaColor) );
-      theColor.setRgb ( listColorKeys[t]->theColor );
-      colorKeyNode.setAttribute ( MANIPULATOR_COLOR, QString ("%1").arg (theColor.name()) );
-      manipulatorNode.appendChild (colorKeyNode);
+      Rgba        theColor ( listColorKeys[t]->theColor );
+      if ( listColorKeys[t]->fDeltaColor != 0.0 )
+	colorKeyNode.setAttribute ( MANIPULATOR_DELTA, QString ("%1").arg ( listColorKeys[t]->fDeltaColor ) );
+      colorKeyNode.setAttribute   ( MANIPULATOR_COLOR, theColor.toString ( ) );
+      manipulatorNode.appendChild ( colorKeyNode );
     }
     theElement.appendChild( manipulatorNode );
   }
@@ -341,91 +425,109 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
   return true;
 }
 
-void ImageManipulator::createStructure (QListViewItem *pParentItem)
+StructureItem *ImageManipulator::createStructure ( StructureItem *pParentItem, StructureItem *pPreviousItem )
 {
-	QListViewItem *pModifierItem;
-	QString qsName;
+  QString qsName;
 
-	ImageManipulator initialValues;
-	// And finally we create the modifiers info ...
-	if ( !( 	(fRotate       == initialValues.fRotate)       &&
-			(fShearX       == initialValues.fShearX)       &&
-			(fShearY       == initialValues.fShearY)       &&
-			(fZoom         == initialValues.fZoom)         &&
-			(fBrightness   == initialValues.fBrightness)   &&
-			(fTransparency == initialValues.fTransparency) &&
-			(fRed          == initialValues.fRed)          &&
-			(fGreen        == initialValues.fGreen)        &&
-			(fBlue         == initialValues.fBlue)         &&
-			(iStartFrame   == initialValues.iStartFrame)   &&
-			(iStopFrame    == initialValues.iStopFrame)    &&
-			(listColorKeys.count() > 0) ) )	{
-		pModifierItem = new QListViewItem(pParentItem, QString ("Modifiers"), NULL);
-		pParentItem->setExpandable (TRUE);
+  ImageManipulator initialValues;
+  // And finally we create the modifiers info ...
+  if ( !( ( fRotate       == initialValues.fRotate)       &&
+	  ( fShearX       == initialValues.fShearX)       &&
+	  ( fShearY       == initialValues.fShearY)       &&
+	  ( fStartX       == initialValues.fStartX)       &&
+	  ( fStartY       == initialValues.fStartY)       &&
+	  ( fKenBurnsX1   == initialValues.fKenBurnsX1)   &&
+	  ( fKenBurnsY1   == initialValues.fKenBurnsY1)   &&
+	  ( fKenBurnsX2   == initialValues.fKenBurnsX2)   &&
+	  ( fKenBurnsY2   == initialValues.fKenBurnsY2)   &&
+	  ( fZoom         == initialValues.fZoom)         &&
+	  ( fScaleX       == initialValues.fScaleX)       &&
+	  ( fScaleY       == initialValues.fScaleY)       &&
+	  ( fBrightness   == initialValues.fBrightness)   &&
+	  ( fTransparency == initialValues.fTransparency) &&
+	  ( fRed          == initialValues.fRed)          &&
+	  ( fGreen        == initialValues.fGreen)        &&
+	  ( fBlue         == initialValues.fBlue)         &&
+	  ( iStartFrame   == initialValues.iStartFrame)   &&
+	  ( iStopFrame    == initialValues.iStopFrame)    &&
+	  ( listColorKeys.count() > 0) ) )  {
+	  
+    StructureItem *pTemp=NULL;
+    if ( ! m_pStructureItem ) {
+      MenuObject *pMenuObject = pParentItem->getMenuObject ( );
+      m_pStructureItem = new StructureItem ( pMenuObject, pParentItem, pPreviousItem, QObject::tr ( "Modifiers" ), NULL );
+      pParentItem->setExpandable ( TRUE );
+    }
 
-		if (	(fRed        != initialValues.fRed)   ||
-			(fGreen      != initialValues.fGreen) ||
-			(fBlue       != initialValues.fBlue) )
-			new QListViewItem(pModifierItem, QString ("Color Adjust"),
-				QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
-		if (fBrightness  != initialValues.fBrightness)
-			new QListViewItem(pModifierItem, QString ("Brightness"),
-				QString ("%1").arg(fBrightness));
-		if (fTransparency  != initialValues.fTransparency)
-			new QListViewItem(pModifierItem, QString ("Transparency"),
-				QString ("%1").arg(fTransparency));
-		if ((fShearX  != initialValues.fShearX) ||
-			(fShearY  != initialValues.fShearY)  )
-			new QListViewItem(pModifierItem, QString ("Shear (x, y)"),
-				QString ("%1, %2").arg(fShearX).arg(fShearY));
-		if ((iStartFrame  != initialValues.iStartFrame) ||
-			(iStopFrame  != initialValues.iStopFrame)  )
-			new QListViewItem(pModifierItem, QString ("VisibleFromTo"),
-				QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
-		if (fZoom  != initialValues.fZoom)
-			new QListViewItem(pModifierItem, QString ("Zoom"),
-				QString ("%1").arg(fZoom));
-		if (fRotate  != initialValues.fRotate)
-			new QListViewItem(pModifierItem, QString ("Rotate"),
-				QString ("%1 deg").arg(fRotate));
-		if (listColorKeys.count() > 0)	{
-			QString qsColorKeys("|");
-			for (uint t=0;t<listColorKeys.count();t++)
-				qsColorKeys += QString("0x%1|").arg(listColorKeys[t]->theColor, 16);
-			new QListViewItem (pModifierItem, QString ("ColorKey"), qsColorKeys);
-		}
-	}
+    pTemp   = (StructureItem *)m_pStructureItem->firstChild ( );
+    while  ( pTemp ) {
+      delete pTemp;
+      pTemp = (StructureItem *)m_pStructureItem->firstChild ( );
+    }
+    
+    if ( ( fRed   != initialValues.fRed   ) ||
+	 ( fGreen != initialValues.fGreen ) ||
+	 ( fBlue  != initialValues.fBlue  ) )
+      new StructureItem ( m_pStructureItem, QObject::tr ("Color Adjust"),  QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
+    if ( fBrightness    != initialValues.fBrightness )
+      new StructureItem ( m_pStructureItem, QObject::tr ("Brightness"),    QString ("%1").arg(fBrightness));
+    if ( fTransparency  != initialValues.fTransparency )
+      new StructureItem ( m_pStructureItem, QObject::tr ("Transparency"),  QString ("%1").arg(fTransparency));
+    if ( ( fShearX      != initialValues.fShearX ) || ( fShearY  != initialValues.fShearY)  )
+      new StructureItem ( m_pStructureItem, QObject::tr ("Shear (x, y)"),  QString ("%1, %2").arg(fShearX).arg(fShearY));
+    if ( ( iStartFrame  != initialValues.iStartFrame ) || ( iStopFrame  != initialValues.iStopFrame) )
+      new StructureItem ( m_pStructureItem, QObject::tr ("VisibleFromTo"), QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
+    if ( fZoom  != initialValues.fZoom )
+      new StructureItem ( m_pStructureItem, QObject::tr ( "Zoom" ), QString ("%1").arg ( fZoom ) );
+    if ( fRotate  != initialValues.fRotate )
+      new StructureItem ( m_pStructureItem, QObject::tr ("Rotate"), QString ("%1 deg").arg ( fRotate ) );
+    if ( listColorKeys.count ( ) > 0 )  {
+      QString qsColorKeys ( "|" );
+      for ( uint t=0; t<listColorKeys.count ( ); t++ )
+	qsColorKeys += QString ( "0x%1|" ).arg ( listColorKeys[t]->theColor, 16 );
+      new StructureItem ( m_pStructureItem, QObject::tr ( "ColorKey" ), qsColorKeys );
+    }
+  }
+  return m_pStructureItem;
 }
 
 ImageManipulator& ImageManipulator::operator = (ImageManipulator &theOther)
 {
-	uint t;
-	backgroundFileName  = theOther.backgroundFileName;
-	bShowBackground     = theOther.bShowBackground;
-	fStartX             = theOther.fStartX;
-	fStartY             = theOther.fStartY;
-	iXRes               = theOther.iXRes;
-	iYRes               = theOther.iYRes;
-	iTransformationMode = theOther.iTransformationMode;
-	fAspectRatio        = theOther.fAspectRatio;
-	fShearX             = theOther.fShearX;
-	fShearY             = theOther.fShearY;
-	iStartFrame         = theOther.iStartFrame;
-	iStopFrame          = theOther.iStopFrame;
-	fZoom               = theOther.fZoom;
-	fRotate             = theOther.fRotate;
-	fRed                = theOther.fRed;
-	fGreen              = theOther.fGreen;
-	fBlue               = theOther.fBlue;
-	fBrightness         = theOther.fBrightness;
-	fTransparency       = theOther.fTransparency;
-	if (listColorKeys.count())	{
-		for (t=0;t<listColorKeys.count();t++)
-			delete listColorKeys[t];
-		listColorKeys.clear();
-	}
-	for (t=0;t<theOther.listColorKeys.count();t++)
-		listColorKeys.append(new colorKeying (theOther.listColorKeys[t]));
-	return *this;
+  uint t;
+  backgroundFileName  = theOther.backgroundFileName;
+  bShowBackground     = theOther.bShowBackground;
+  fStartX             = theOther.fStartX;
+  fStartY             = theOther.fStartY;
+  fKenBurnsX1         = theOther.fKenBurnsX1;
+  fKenBurnsY1         = theOther.fKenBurnsY1;
+  fKenBurnsX2         = theOther.fKenBurnsX2;
+  fKenBurnsY2         = theOther.fKenBurnsY2;
+  iXRes               = theOther.iXRes;
+  iYRes               = theOther.iYRes;
+  iTransformationMode = theOther.iTransformationMode;
+  fAspectRatio        = theOther.fAspectRatio;
+  fShearX             = theOther.fShearX;
+  fShearY             = theOther.fShearY;
+  iStartFrame         = theOther.iStartFrame;
+  iStopFrame          = theOther.iStopFrame;
+  fZoom               = theOther.fZoom;
+  fScaleX             = theOther.fScaleX;
+  fScaleY             = theOther.fScaleY;
+  fRotate             = theOther.fRotate;
+  fRed                = theOther.fRed;
+  fGreen              = theOther.fGreen;
+  fBlue               = theOther.fBlue;
+  fBrightness         = theOther.fBrightness;
+  fTransparency       = theOther.fTransparency;
+  if (listColorKeys.count())	{
+    for (t=0;t<listColorKeys.count();t++)
+      delete listColorKeys[t];
+    listColorKeys.clear();
+  }
+  for (t=0;t<theOther.listColorKeys.count();t++)
+    listColorKeys.append(new colorKeying (theOther.listColorKeys[t]));
+
+  return *this;
 }
 
+
