@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 **  pure virtual class as base for the three button types.
 **
@@ -32,23 +34,27 @@ public:
 	virtual void drawContents       ( QPainter *, int, int );
 	virtual bool readProjectFile    ( QDomNode & );
 	virtual bool writeProjectFile   ( QDomElement & );
-	virtual void createStructure    ( QListViewItem * );
-	virtual bool createContextMenu  ( QPoint );
-	virtual MenuObject *clone       ( );
+	virtual bool createContextMenu  ( QPoint  );
+	virtual void setFile            ( QString );
+	virtual StructureItem *createStructure ( StructureItem * );
+	virtual MenuObject    *clone    ( QWidget *p=NULL, MenuObject *p2=NULL );
 
 	virtual void setPixmap          ( QPixmap & );
 	virtual void updatePixmap       ( );
+	virtual QString &extractionPath ( );  // dynamically create this one
 
 	void     setStartAfterDropEvent ( bool   );
 	void     setExtracted           ( bool   );
 	void     setDVDMenu             ( DVDMenu *, bool b=false);
 	void     setOffset              ( QTime &);
 	void     setDuration            ( QTime &);
+	void     setMenuLength          ( bool   );
 	void     setMSecPreview         ( long   );
 	void     setNiceness            ( int    );
 	void     setMovieSize           ( QSize &);
 	QTime   &offset                 ( );
 	QTime   &duration               ( );
+	bool     isMenuLength           ( );
 	long     msecPreview            ( );
 	QSize   &movieSize              ( );
 	QImage  *previewImage           ( );
@@ -56,18 +62,20 @@ public:
 
 	void    setDragNDropValues      ( DragNDropContainer *);
 	void    registerToRender        ( );
+	void    startConverting         ( bool );
 
 protected:
 	virtual AnimationAttribute *getSpecificAttributes (long, QString);
 	virtual void timerEvent         ( QTimerEvent *);	// called after the preview has been rendered in a child task.
 	void loadPixmap                 ( QString);
+	void createExtractionPath       ( );
 
 public slots:
 	virtual void slotStartConverting( );
+	virtual void slotProperties     ( );
 
 protected slots:
 	virtual void slotEdit           ( );
-	virtual void slotProperties     ( );
 	virtual void slotSetThumbnail   ( long );
 
 /* Handled in base class ImageObject
@@ -88,6 +96,7 @@ protected:
 	long     m_iMSecPreview;
 	QTime    m_timeOffset;
 	QTime    m_timeDuration;
+	bool     m_bMenuLength;
 	QImage   m_imagePreview;	// used to create a preview in a background task.
 	int      m_iHowNiceShouldIBe;
 	bool     m_bStartAfterDropEvent;
