@@ -13,6 +13,9 @@
 #include "uidialogchapters.h"
 #include "../sourcefileentry.h"
 
+class MediaInterface;
+class StartStopSlider;
+class StartStopControl;
 
 class DialogChapters : public uiDialogChapters
 {
@@ -21,8 +24,10 @@ public:
 	 DialogChapters (QWidget * parent, const char * name = 0, WFlags f = 0 );
 	~DialogChapters ();
 
-	void initMe(SourceFileInfo *);
-	SourceFileInfo *getSourceFileInfo ();
+	void initMe(SourceFileInfo *,  const void *, int=0);
+	void initMe(SourceFileEntry *, const void *, int=0);
+	SourceFileInfo  *getSourceFileInfo  ();
+	SourceFileEntry *getSourceFileEntry ();
 
 private:
 	void preview ();
@@ -34,11 +39,19 @@ protected slots:
 	virtual void slotDelChapters  ();
 	virtual void slotAutoChapters ();
 	virtual void slotPreview      ();
-	virtual void slotHighlighted  (int);
+	virtual void slotCurrentChanged (QListBoxItem *);
 	virtual void accept ();
+	virtual void slotNewPosition(int, const QString &);
 
 private:
-	SourceFileInfo m_sourceFileInfo;
+	SourceFileInfo    m_sourceFileInfo;
+	SourceFileEntry   m_sourceFileEntry;
+	MediaInterface   *m_pMediaInterface;
+	StartStopControl *m_pStartStopControl;
+	QString           m_qsPosition;
+	int               m_iMovieLength;
+	// TODO: delete these two old entries ...
+//	QLabel           *m_pLabelSlider;
 };
 
 #endif // DIALOGCHAPTERS_H
