@@ -14,9 +14,9 @@
 #include <qstringlist.h>
 #include <qfileinfo.h>
 #include <qprocess.h>
-#include <qwidget.h>
-//#include <qregexp.h>
 #include <qstring.h>
+#include <qwidget.h>
+#include <qtimer.h>
 #include <qfile.h>
 #include <qdir.h>
 #include <qdom.h>
@@ -79,7 +79,7 @@ bool QMPlayerWidget::start(QStringList *pEnvironment)
 	listCommand.append(QString("-ontop"));
 
 	listCommand.append(QString("-wid"));
-	listCommand.append(QString("%1").arg(winId()));
+	listCommand.append(QString("%1").arg((long)winId()));
 	listCommand.append(QString("-slave"));
 	if (!m_listPluginOptions[QMPlayerWidget::AudioPlugin].isEmpty())	{
 		listCommand.append(QString("-ao"));
@@ -96,15 +96,33 @@ bool QMPlayerWidget::start(QStringList *pEnvironment)
 
 	listCommand.append(QString("-identify"));
 	listCommand.append(QString("-framedrop"));
-	listCommand.append(QString("--"));
-	listCommand.append(QString("%1").arg(m_qsFileName));
+	if ( m_qsFileName.find ( "dvd://" ) > -1 ) {
+	  QString qsTemp = m_qsFileName;
+	  qsTemp.remove ( "dvd:/" );
+	  QFileInfo fileInfo ( qsTemp );
+	  if ( fileInfo.isDir  ( ) ) {
+	    listCommand.append ( "-dvd-device" );
+	    listCommand.append ( qsTemp );
+	    listCommand.append ( QString  ( "--" ) );
+	    listCommand.append ( "dvd://1" );
+	  }
+	  else if ( fileInfo.exists ( ) ) {
+	    listCommand.append ( QString  ( "--" ) );
+	    listCommand.append ( qsTemp );
+	  }
+	}
+	else {
+	  listCommand.append(QString ( "--" ) );
+	  listCommand.append ( m_qsFileName ); //QString("%1").arg(m_qsFileName));
+	}
 
 	// -ss 01:10:00 seeks to 1 hour 10 min
 	m_fLength = 0.0;
+	// printf ( "command < %s >\n", listCommand.join ( " " ).ascii ( ) );
 
-	m_pMasterProcess->setArguments (listCommand);
+	m_pMasterProcess->setArguments ( listCommand  );
 	emit (signalMPlayerStarted());
-	return m_pMasterProcess->start(pEnvironment);
+	return m_pMasterProcess->start ( pEnvironment );
 }
 
 void QMPlayerWidget::loadInitFile ()
@@ -116,7 +134,7 @@ void QMPlayerWidget::loadInitFile ()
 
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_ReadWrite))
+	if (!iniFile.open(IO_ReadOnly))
 		return;
 	// Try to get the right xml contents ...
 	QDomDocument xmlDoc( XML_DOCTYPE_MPLAYER );
@@ -188,7 +206,7 @@ void QMPlayerWidget::saveInitFile ()
 
 	// Assign the file
 	QFile iniFile(qsPlayerIniFile);
-	if (!iniFile.open(IO_ReadWrite))
+	if (!iniFile.open(IO_WriteOnly))
 		return;
 
 	QString xml = xmlDoc.toString();
@@ -260,6 +278,67 @@ void QMPlayerWidget::slotLaunchFinished ()
 {
 }
 
+void QMPlayerWidget::slotNavigate ( int nav )
+{
+  QString qsBuffer="dvdnav up\n";
+  switch ( nav ) {
+  case 0:
+    qsBuffer="dvdnav up\n";
+  break;
+  case 1:
+    qsBuffer="dvdnav down\n";
+  break;
+  case 2:
+    qsBuffer="dvdnav left\n";
+  break;
+  case 3:
+    qsBuffer="dvdnav right\n";
+  break;
+  case 4:
+    qsBuffer="dvdnav select\n";
+  break;
+  };
+  writeToStdin ( qsBuffer );
+}
+
+void QMPlayerWidget::slotMenu ( int menu )
+{
+  if ( m_qsFileName.find ( "dvd://" ) > -1 ) {
+    QString qsFile = m_qsFileName;
+    qsFile = qsFile.remove ( "dvd:/" );
+    qsFile += "/VIDEO_TS.VOB";
+    QFileInfo fileInfo ( qsFile );
+    if ( fileInfo.exists ( ) )
+      m_qsFileName = qsFile;
+  }
+  if ( m_qsFileName.find ( "VIDEO_TS.VOB" ) > -1 ) {
+    slotStop ( );
+    QTimer::singleShot ( 100, this, SLOT ( slotPlay ( ) ) );
+    return;
+  }
+
+  // Does currently not work in MPLayer ...
+  QString qsBuffer="set_menu root\n";
+  if ( menu == 0 )
+    qsBuffer="set_menu root\n";
+  else if ( menu == 1 )
+    qsBuffer="set_menu title\n";
+    
+  writeToStdin ( qsBuffer );
+}
+
+void QMPlayerWidget::slotSubtitleTrack ( int iTrackNumber )
+{
+  QString qsBuffer = QString ( "sub_select %1\n" ).arg ( iTrackNumber );
+  writeToStdin ( qsBuffer );
+}
+
+void QMPlayerWidget::slotAudioTrack ( int iTrackNumber )
+{
+  QString qsBuffer = QString ( "switch_audio %1\n" ).arg ( iTrackNumber );
+  writeToStdin ( qsBuffer );
+}
+
 void QMPlayerWidget::writeToStdin(QString &qsBuffer)
 {
 	m_pMasterProcess->writeToStdin(qsBuffer.latin1());
@@ -311,6 +390,16 @@ void QMPlayerWidget::slotSetSpeed(float fValue)
 
 void QMPlayerWidget::slotSetVolume(float fValue)
 {
+  // There are two volume modes. Static and dynamic.
+  // Static is in the range between [0 and 100]
+  // Dynamic inc / dec the volume percentage wise [ -100 .. +100 ]
+  int     iVolume  = (int)( fValue );
+  QString qsBuffer = QString ( "volume %1 1\n" ).arg( iVolume );
+  writeToStdin ( qsBuffer );
+}
+/*
+void QMPlayerWidget::slotSetVolume(float fValue)
+{ // Dynamic mode
   // The slave mode seems to take relative values for the volume,
   // thus to quiet things down values between [0.0 and 1.0[
   // To increase volume values between [1.0 and oo[
@@ -324,10 +413,12 @@ void QMPlayerWidget::slotSetVolume(float fValue)
   QString qsBuffer = QString ( "volume %1\n" ).arg( fVolume );
   writeToStdin ( qsBuffer );
 }
-
+*/
 void QMPlayerWidget::slotScreenshot()
 {
-	system (QString("rm %1").arg(m_qsScreenshotName));
+
+	int iRet = system (QString("rm -f %1").arg(m_qsScreenshotName));
+	iRet = iRet;
 	QString qsBuffer = QString("screenshot %1\n").arg(m_qsScreenshotName);
 	writeToStdin (qsBuffer);
 	// Next we verify that the file has been created.
@@ -375,14 +466,14 @@ void QMPlayerWidget::setAspectRatio (uint iAspectRatio)
 		return;
 	break;
 	case ASPECT_34:
-		fAspectRatio = 3.0 / 4.0;
+		fAspectRatio = 3.0f / 4.0f;
 	break;
 	case ASPECT_169:
-		fAspectRatio = 16.0 / 9.0;
+		fAspectRatio = 16.0f / 9.0f;
 	break;
 	case ASPECT_SQUARE:
 	default:
-		fAspectRatio = 1.0;
+		fAspectRatio = 1.0f;
 	break;
 	}
 	qsBuffer.sprintf("switch_aspect %f\n", fAspectRatio);
