@@ -24,7 +24,7 @@ public:
 	virtual ~VLCInfo ();
 
 	// Mandatory function getScreenshot ()
-	virtual QImage getScreenshot(uint);
+	virtual QImage getScreenshot ( long );
 protected:
 	// Mandatory function queryValues ()
 	virtual void queryValues ();
