@@ -1,4 +1,9 @@
 /***************************************************************************
+**
+**   Created : Tue Jan 02 22:06:51 2004
+**        by : Varol Okan using Kate
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 ** Class hirachy ...
 **
 **
@@ -95,13 +100,13 @@ QStringList MediaCreator::getAvailableEngines ()
 	static QStringList listEngines;
 	listEngines.clear();
 	listEngines.append(QString("DummyWidget"));	// Dummy interface in case we encounter an error
-#if (XINE_SUPPORT == 1)
-	listEngines.append(QString("QXineWidget"));	// From an older version of the QDVDAuthor project -> interface class = XineWidget
-	listEngines.append(QString("KXineWidget"));	// From the kaffeine - project -> interface class = KaffeinesWidget
-#endif
 #if (MPLAYER_SUPPORT == 1)
 	listEngines.append(QString("QMPlayerWidget"));	// Self designed Widget -> interface class = MPlayerWidget
 #endif
+#if (XINE_SUPPORT == 1)
+	listEngines.append(QString("KXineWidget"));	// From the kaffeine - project -> interface class = KaffeinesWidget
+	listEngines.append(QString("QXineWidget"));	// From an older version of the QDVDAuthor project -> interface class = XineWidget
+#endif
 #if (VLC_SUPPORT == 1)
 	listEngines.append(QString("QVLCWidget"));	// interface class = VLCWidget
 #endif
@@ -230,22 +235,61 @@ MediaInfo *MediaCreator::createInfo(void *pVoid)
 
 void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, QString &qsFileName, QImage *pImage, long iMSecondsOffset)
 {
-	// The first action to take is a sanity check ...
-	if ( (!pImage) || (!pOrigObject) )
-		return;
-	// First we create the ExecuteObject (Container to store the information) 
-	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, qsFileName, pImage, iMSecondsOffset);
-	
-	// Check if we need to create a new object ...
-	if (MediaCreator::pPreviewObject == NULL)
-		MediaCreator::pPreviewObject = new MediaScanner;
-	else if ((!MediaCreator::pPreviewObject->running()) && (MediaCreator::pPreviewObject->hasFinished()))	{
-		// If the object already exist and it has finished running, 
-		// THEN delete the old and create a new one
-		delete MediaCreator::pPreviewObject;
-		MediaCreator::pPreviewObject = new MediaScanner;
-	}
-	MediaCreator::pPreviewObject->append (pNewJob);
+  // The first action to take is a sanity check ...
+  if ( (!pImage) || (!pOrigObject) )
+    return;
+  // First we create the ExecuteObject (Container to store the information) 
+  ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, qsFileName, pImage, iMSecondsOffset);
+  MediaCreator::ensureMediaScannerExists ( );
+  
+  MediaCreator::pPreviewObject->append (pNewJob);
+}
+
+void MediaCreator::registerWithMediaScanner ( QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, long iMSecondsOffset, bool bUpdateAllInfo )
+{
+  // THe first action to take is a sanity check ...
+  if ( (!pSourceFileInfo) || (!pOrigObject) )
+    return;
+  // First we create the ExecuteObject (Container to store the information) 
+  ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, pSourceFileInfo, iMSecondsOffset, bUpdateAllInfo );
+  MediaCreator::ensureMediaScannerExists ( );
+  
+  MediaCreator::pPreviewObject->append (pNewJob);
+}
+
+void MediaCreator::registerWithMediaScanner ( QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, Subtitles *pSubtitles, float fFPS )
+{
+  // THe first action to take is a sanity check ...
+  if ( ( ! pSourceFileInfo ) || ( ! pSubtitles ) )
+    return;
+  // First we create the ExecuteObject   ( Container to store the information ) 
+  ExecuteJob *pNewJob = new ExecuteJob   ( pOrigObject, pSourceFileInfo, pSubtitles, fFPS );
+  MediaCreator::ensureMediaScannerExists ( );
+  MediaCreator::pPreviewObject->append   ( pNewJob );
+}
+
+void MediaCreator::registerWithMediaScanner ( ExecuteJob *pJob )
+{
+  // THe first action to take is a sanity check ...
+  if ( ! pJob )
+    return;
+
+  MediaCreator::ensureMediaScannerExists ( );
+  MediaCreator::pPreviewObject->append   ( pJob );
+}
+
+void MediaCreator::ensureMediaScannerExists ( )
+{
+  // Check if we need to create a new object ...
+  if ( MediaCreator::pPreviewObject == NULL )
+       MediaCreator::pPreviewObject = new MediaScanner;
+  else if ( ( ! MediaCreator::pPreviewObject->running     ( ) ) && 
+	    (   MediaCreator::pPreviewObject->hasFinished ( ) ) ) {
+    // If the object already exist and it has finished running, 
+    // THEN delete the old and create a new one
+    delete MediaCreator::pPreviewObject;
+    MediaCreator::pPreviewObject = new MediaScanner;
+  }
 }
 
 void MediaCreator::unregisterFromMediaScanner (QObject *pObject)
@@ -260,23 +304,4 @@ void MediaCreator::unregisterFromMediaScanner (SourceFileInfo *pSourceFileInfo)
        MediaCreator::pPreviewObject->remove ( pSourceFileInfo );
 }
 
-void MediaCreator::registerWithMediaScanner (QObject *pOrigObject, SourceFileInfo *pSourceFileInfo, long iMSecondsOffset, bool bUpdateAllInfo )
-{
-	// THe first action to take is a sanity check ...
-	if ( (!pSourceFileInfo) || (!pOrigObject) )
-		return;
-	// First we create the ExecuteObject (Container to store the information) 
-	ExecuteJob *pNewJob = new ExecuteJob (pOrigObject, pSourceFileInfo, iMSecondsOffset, bUpdateAllInfo );
-	
-	// Check if we need to create a new object ...
-	if (MediaCreator::pPreviewObject == NULL)
-		MediaCreator::pPreviewObject = new MediaScanner;
-	else if ((!MediaCreator::pPreviewObject->running()) && (MediaCreator::pPreviewObject->hasFinished()))	{
-		// If the object already exist and it has finished running, 
-		// THEN delete the old and create a new one
-		delete MediaCreator::pPreviewObject;
-		MediaCreator::pPreviewObject = new MediaScanner;
-	}
-	MediaCreator::pPreviewObject->append (pNewJob);
-}
 
