@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Implementation of class MediaInfo
 **
-** Created: Tue Nov 9 07:53:05 2004
-**      by: Varol Okan using the kate editor
+**   Created : Tue Nov 9 07:53:05 2004
+**        by : Varol Okan using the kate editor
+** Copyright : (c) Varol Okan
+**   License : GPL v 2.0
 **
 ** This class collects all possible information about
 ** the current set stream.
@@ -18,9 +20,10 @@
 
 MediaInfo::MediaInfo (void *pMediaEngine)
 {
-	m_pMediaEngine = NULL;
-	initMe ();
-	setMediaEngine (pMediaEngine);
+  m_bUseEventLoop = true;
+  m_pMediaEngine  = NULL;
+  initMe ( );
+  setMediaEngine ( pMediaEngine );
 }
 
 MediaInfo::~MediaInfo ()
@@ -48,6 +51,16 @@ void MediaInfo::initMe ()
 	m_qsStatus = QObject::tr ("Not Ok");
 }
 
+bool MediaInfo::useEventLoop ( )
+{
+  return m_bUseEventLoop;
+}
+
+void MediaInfo::setUseEventLoop ( bool bUseEventLoop )
+{
+  m_bUseEventLoop = bUseEventLoop;
+}
+
 void *MediaInfo::getMediaEngine ()
 {
 	return m_pMediaEngine;
@@ -59,34 +72,39 @@ void MediaInfo::setMediaEngine  (void *pMediaEngine)
 		m_pMediaEngine = pMediaEngine;
 }
 
-void MediaInfo::setFileName (QString qsStream)
+void MediaInfo::setFileName ( QString qsStream, bool bQueryValues )
 {
-	// Next we check if the file exists ...
-	QFileInfo fileInfo (qsStream);
-	if (!fileInfo.exists())	{
-	  wLOG ("File not found %s", (const char *)qsStream);
-	  return;
-	}
+  // First we chack if we want to play a DVD, no info avail at this point in time ...
+  if ( qsStream.find ( "dvd://" ) > -1 )
+    return;
 
-	// Set the file size ...
-	m_iSize = fileInfo.size();
-	if (m_iSize < 1)
-		m_qsSize = QString ("? B");
-	if (m_iSize < 1024)
-		m_qsSize = QString ("%1 B").arg(m_iSize);
-	else if (m_iSize < 1024*1024)
+  // Next we check if the file exists ...
+  QFileInfo fileInfo ( qsStream );
+  if ( ! fileInfo.exists ( ) )  {
+    printf ("File not found %s\n", (const char *)qsStream);
+    return;
+  }
+
+  // Set the file size ...
+  m_iSize = fileInfo.size();
+  if (m_iSize < 1)
+    m_qsSize = QString ("? B");
+  if (m_iSize < 1024)
+    m_qsSize = QString ("%1 B").arg(m_iSize);
+  else if (m_iSize < 1024*1024)
 		m_qsSize = QString ("%1kB").arg((float)m_iSize/1024);
-	else if (m_iSize < 1024*1024*1024)
-		m_qsSize = QString ("%1MB").arg((float)m_iSize/(1024*1024));
-	else
-		m_qsSize = QString ("%1GB").arg((float)m_iSize/(1024*1024*1024));
+  else if (m_iSize < 1024*1024*1024)
+    m_qsSize = QString ("%1MB").arg((float)m_iSize/(1024*1024));
+  else
+    m_qsSize = QString ("%1GB").arg((float)m_iSize/(1024*1024*1024));
 
-	// set the file name ...
-	m_qsFileName = qsStream;
-	// reset the previous values ...
-	initMe();
-	// and now let us query some values ...
-	queryValues ();
+  // set the file name ...
+  m_qsFileName = qsStream;
+  // reset the previous values ...
+  initMe();
+  // and now let us query some values ...
+  if ( bQueryValues )
+        queryValues ( );
 }
 
 QString MediaInfo::getFileName (bool bFullName)
@@ -121,9 +139,9 @@ QString MediaInfo::getExtensions (bool bVideo)
 {
 	QString qsExtension;
 	if (bVideo)
-		qsExtension = QString ("*.mpg *.mpeg *.avi *.mwa *.mov *.wma *.vob *.m2v *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.AVI *.MWA *.MOV *.WMA *.VOB *.M2V *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
+		qsExtension = QString ("*.mpg *.mpeg *.mpeg2 *.avi *.mwa *.mov *.wma *.vob *.m2v *.dv *.wmv *.mjpeg *.mve *.asf *.asx *.MPG *.MPEG *.MPEG2 *.AVI *.MWA *.MOV *.WMA *.VOB *.M2V *.DV *.WMV *.MJPEG *.MVE *.ASF *.ASX");
 	else
-		qsExtension = QString("*.wav *.mp3 *.mp2 *.mpa *.mpega *.ogg *.WAV *.MP3 *.MP2 *.MPA *.MPEGA *.OGG");
+		qsExtension = QString("*.wav *.mp3 *.mp2 *.ac3 *.m2a *.mpa *.mpega *.ogg *.WAV *.MP3 *.MP2 *.AC3 *.M2A *.MPA *.MPEGA *.OGG");
 
 	return qsExtension;
 }
