@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Tue 04 May 12:09:08 2004
-**      by: Varol Okan using kate editor
+**   Created : Tue 04 May 12:09:08 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
 **
 ** This class will create a toolbar, which displays all currently selected
 ** sources for the DVD, such as all Videos, and all Audio files.
@@ -24,7 +26,7 @@
 #ifndef SOURCETOOLBAR_H
 #define SOURCETOOLBAR_H
 
-#include <qtoolbar.h>
+#include <qdockwindow.h>
 
 // The following two defines specify which column the file name is to be found. 
 #define MOVIE_FILE_NAME_INDEX 7
@@ -39,29 +41,33 @@
 class QDVDAuthor;
 class MediaInfo;
 class CSlideDialog;
+class DialogThumbnail;
 
-class SourceToolBar : public QToolBar
+class SourceToolBar : public QDockWindow
 {
 	Q_OBJECT
 
 public:
-	 SourceToolBar     ( const QString &, QMainWindow *, QWidget *, bool b=FALSE, const char *n=0, WFlags f=0 );
+	 SourceToolBar     ( const char *, QMainWindow * );
 	~SourceToolBar     ( );
  
-	void addMovie      (SourceFileEntry * );
+	void addMovie      ( SourceFileEntry * );
 	void addMovieList  ( QStringList &, QString *p=NULL );
 	void addSound      ( QStringList & );
 	void clear         ( );
 	
-	int sourceFileCount                        ( );
+	int  sourceFileCount                       ( );
 	int  getFreeSourceSlot                     ( );
 	SourceFileEntry *sourceFileEntry           ( uint );
 	SourceFileEntry *getCurrentSourceFileEntry ( );
 	SourceFileInfo  *getCurrentSourceFileInfo  ( );
-	bool checkRightFileFormat                  ( SourceFileInfo * );
-	void appendSourceFileEntry                 ( SourceFileEntry * );
-	void removeEntry                           ( QString &, bool b=true );
-	void removeEntry                           ( SourceFileEntry *, bool b=true );
+	void updateListViewItem                    ( SourceFileInfo  * );
+	bool checkRightAudioFormat                 ( SourceFileInfo  * );
+	bool checkRightFileFormat                  ( SourceFileInfo  * );
+	void appendSourceFileEntry                 ( SourceFileEntry *, bool b=false );
+	void removeEntry                           ( SourceFileEntry *, bool b=true  );
+	void removeEntry                           ( QString &, bool  b=true );
+	void updateStatusColor                     ( QListViewItem   *p=NULL );
 
 	virtual QSize sizeHint                     ( ) const;
 	QString convertFileSize                    ( uint );
@@ -76,7 +82,7 @@ private:
 	void *getMediaEngine          ( );
 	void  importChapters          ( QString, SourceFileInfo * );
 	void  updateEntryHeader       ( SourceFileEntry * );
-	void  updateListViewItem      ( SourceFileInfo  * );
+	void  setAudioTranscode       ( SourceFileInfo  * );
 
 public slots:
 	virtual void slotDoubleClickedOnVideoList( QListViewItem *, const QPoint &, int );
@@ -84,12 +90,16 @@ public slots:
 	virtual void slotClickedOnVideoList      ( QListViewItem *, const QPoint &, int );
 	virtual void slotPlayMovie    ( );
 	virtual void slotEditMovie    ( );
+	virtual void slotEditAudio    ( );
 	virtual void slotDeleteSource ( );
 	virtual void slotTranscodeAll ( );
-
+	virtual void slotAllToTitleset( );
+	virtual void slotToNewSubmenu ( );
+	virtual void slotAddMovieOld  ( );
 	virtual void slotAddMovie     ( );
 	virtual void slotAddSound     ( );
 	virtual void slotAddSlideshow ( );
+	virtual void slotThumbnailing ( );
 	virtual void slotSetThumbnail ( long );
 	virtual void slotAddSlideshow ( QString );
 	virtual void slotSlideshowDone( QString, QString );
@@ -100,6 +110,7 @@ private:
 	QMutex             m_mutexThumbnails;
 	MediaInfo         *m_pMediaInfo;
 	CSlideDialog      *m_pSlideDialog;
+	DialogThumbnail   *m_pThumbnailDialog;
 	QDVDAuthor        *m_pDVDAuthor;
 	QListView         *m_pListViewAllSources;
 	QValueList<SourceFileEntry *>	m_listSourceFileEntries;
