@@ -1,8 +1,10 @@
 /****************************************************************************
 ** TemplateWizard class
 **
-** Created: Mon May 23 12:09:08 2005
-**      by: Varol Okan using kate editor
+**   Created : Mon May 23 12:09:08 2005
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
 **
 ** This class allows the user to choose a template and simply fillin the 
 ** blanks.
@@ -90,7 +92,6 @@ public:
 	void initMe             ( QDVDAuthor * );
 	void droppedSomething   ( QDropEvent * );
 	void showDialog         ( );
-	DVDMenu *getMenu        ( );
 
 protected:
 	void initTab (QString, QIconView * );
@@ -98,8 +99,11 @@ protected:
 	void initDragList                 ( );
 	void refreshBackground            ( );
 	void refreshComboMenu             ( );
+	void handleMenuAudio              ( );
 	QString getSourceEntryName( QString );
-	QString readProjectFile ( QString, bool );
+	QString readProjectFile   ( QString, bool );
+	void adjustPixmapHeight   ( QPixmap *, QString & );
+	void refreshMovieButtons  ( DVDMenu * );
 
 protected slots:
 	virtual void slotTemplateClicked   (QMouseEvent   *);
@@ -117,7 +121,6 @@ protected slots:
 private:
 	QDVDAuthor              *m_pDVDAuthor;
 	TemplateFrame           *m_pFrameProperties;
-	DVDMenu                 *m_pDVDMenu;
 	MediaInterface          *m_pMediaInterface;
 	ListBoxToolTip          *m_pListBoxToolTip;
 	bool                     m_bDontRestart;
