@@ -1,8 +1,10 @@
 /****************************************************************************
 ** Interface to the GUI.
 **
-** Created: Sun Feb 23 21:45:00 2004
-**      by: Varol Okan using kate editor
+**   Created : Sun Feb 23 21:45:00 2004
+**        by : Varol Okan using kate editor
+** Copyright : (c) Varol Okan
+** License   : GPL v 2.0
 **
 **  pure virtual class as base for the three button types.
 **
@@ -30,23 +32,23 @@ public:
 
 	virtual bool readProjectFile       ( QDomNode      & );
 	virtual bool writeProjectFile      ( QDomElement   & );
-	virtual void createStructure       ( QListViewItem * );
 	virtual bool createContextMenu     ( QPoint );
-	virtual MenuObject *clone          ( );
-	virtual void replaceColor          ( QColor, QColor );
+	virtual StructureItem *createStructure ( StructureItem * );
+	virtual MenuObject    *clone       ( QWidget *p1=NULL, MenuObject *p2=NULL );
+	virtual void replaceColor          ( Rgba, Rgba );
 
 	virtual void setFont               ( QFont   & );
 	virtual void setText               ( QString & );
 	virtual void setTextAlign          ( QPoint  & );
-	virtual void setStyleStrategy      ( int);
-	virtual void setForegroundColor    ( const QColor & );
-	virtual void setBackgroundColor    ( const QColor & );
+	virtual void setStyleStrategy      ( int );
+	virtual void setForegroundColor    ( const Rgba & );
+	virtual void setBackgroundColor    ( const Rgba & );
 	virtual QFont   &getFont           ( );
 	virtual QString &getText           ( );
 	virtual QPoint  &getTextAlign      ( );
 	virtual int      getStyleStrategy  ( );
-	virtual QColor  &getForegroundColor( );
-	virtual QColor  &getBackgroundColor( );
+	virtual Rgba    &getForegroundColor( );
+	virtual Rgba    &getBackgroundColor( );
 
 private:
 	void drawSemiTransparent           ( QPainter * );
@@ -66,8 +68,8 @@ protected:
 	QString     m_qsText;
 	QFont       m_Font;
 	QPoint      m_ptTextAlign;
-	QColor      m_colorForeground;
-	QColor      m_colorBackground;
+	Rgba        m_colorForeground;
+	Rgba        m_colorBackground;
 	int         m_iStyleStrategy;
 };
 
