@@ -1,6 +1,13 @@
-/////////////////
-// Hey
-////////////////
+/****************************************************************************
+  ** some defines for XML file creation 
+  **
+  **   Created : 
+  **        by : Varol Okan using kate editor
+  ** Copyright : (c) Varol Okan
+  ** License   : GPL v 2.0
+  **
+  **
+  ****************************************************************************/
 #ifndef XML_DVD_H
 #define XML_DVD_H
 
@@ -11,8 +18,9 @@
 #define THE_PROJECT_NAME "ProjectName"
 
 // The following version number is used for the xml - ProjectFile
+// Version 1.1 RC3 = 1. 01 03
 #define QDVDAUTHOR_VERSION                     "XMLVersion"
-#define QDVDAUTHOR_VERSION_NUMBER              "0.1.2"
+#define QDVDAUTHOR_VERSION_NUMBER              "1.0104"
 
 // Here we goof around with the Templates
 // Nodes
@@ -25,6 +33,7 @@
 #define TEMPLATE_CONTACT                       "Contact"
 #define TEMPLATE_HEADER                        "Header"
 #define TEMPLATE_DESCRIPTION                   "TemplateDescription"
+#define TEMPLATE_CATEGORY                      "TemplateCategory"
 #define TEMPLATE_COMMENT                       "TemplateComment"
 #define TEMPLATE_DROPZONE                      "DropZone"
 
@@ -76,7 +85,7 @@
 #define MENU_MENU_NR                            "MenuNr"
 
 // This one is used for Templates. If nothing has been put into a DropZone, ignore.
-#define IGNORE_OBJECT                            "IgnoreObject"
+#define IGNORE_OBJECT                           "IgnoreObject"
 
 #define ANIMATION_OBJECT                        "AnimationObject"
 
@@ -102,11 +111,24 @@
 
 // ShadowObject - class
 #define SHADOW_OBJECT                           "ShadowObject"
+#define SHADOW_OBJECT_TYPE                      "Type"
 #define SHADOW_OBJECT_COLOR                     "Color"
 #define SHADOW_OBJECT_TRANSPARENCY              "Transparency"
 #define SHADOW_OBJECT_DISTANCE                  "Distance"
 #define SHADOW_OBJECT_BLUR_RADIUS               "BlurRadius"
 #define SHADOW_OBJECT_SUN_ANGLE                 "SunAngle"
+#define SHADOW_OBJECT_SHEAR_X                   "ShearX"
+#define SHADOW_OBJECT_SHEAR_Y                   "ShearY"
+#define SHADOW_OBJECT_SCALE_X                   "ScaleX"
+#define SHADOW_OBJECT_SCALE_Y                   "ScaleY"
+#define SHADOW_OBJECT_CUT_OFF                   "CutOff"
+#define SHADOW_OBJECT_CUT_OFF_RADIUS            "CutOffRadius"
+#define SHADOW_OBJECT_COLOR_FADING              "ColorFading"
+#define SHADOW_OBJECT_COLOR_FADE_TO             "ColorFadeTo"
+
+// Mask is a subset of a shadow object.
+#define MASK_OBJECT                             "MaskObject"
+#define MASK_OBJECT_COLOR                       "Color"
 
 // The TextObject - class
 #define TEXT_OBJECT                             "TextObject"
@@ -126,11 +148,13 @@
 #define MOVIE_OBJECT_FILE_NAME                  "FileName"
 #define MOVIE_OBJECT_OFFSET                     "Offset"
 #define MOVIE_OBJECT_DURATION                   "Duration"
+#define MOVIE_OBJECT_MENU_LENGTH                "MenuLength"
 #define MOVIE_OBJECT_MSEC_PREVIEW               "MSecPreview"
 #define MOVIE_OBJECT_SIZE                       "Size"
 
 // The ObjectCollection - class
 #define OBJECT_COLLECTION                       "ObjectCollection"
+#define SELECTION_OBJECT                        "SelectionObject"
 
 #define BUTTON_OBJECT                           "ButtonObject"
 #define BUTTON_OBJECT_NAME                      "ButtonName"
@@ -138,12 +162,15 @@
 #define BUTTON_OBJECT_SELECTED                  "SelectedState"
 #define BUTTON_OBJECT_HIGHLIGHTED               "HighlightedState"
 #define BUTTON_OBJECT_ACTION                    "Action"
+#define BUTTON_OBJECT_PRE_ACTION                "PreAction"
 #define BUTTON_OBJECT_UP                        "Up"
 #define BUTTON_OBJECT_DOWN                      "Down"
 #define BUTTON_OBJECT_LEFT                      "Left"
 #define BUTTON_OBJECT_RIGHT                     "Right"
 #define BUTTON_OBJECT_SOURCE_ENTRY              "SourceEntry"
 #define BUTTON_OBJECT_MOVEABLE                  "Moveable"
+#define BUTTON_OBJECT_MULTIPLE                  "PlayMe"
+#define BUTTON_OBJECT_LOOP_MULTIPLE             "Loop"
 
 // The SourceFileEntry - class
 #define SOURCE_OBJECT                           "SourceEntry"
@@ -160,7 +187,9 @@
 #define SOURCE_OBJECT_RATIO                     "Ratio"
 #define SOURCE_OBJECT_LENGTH                    "Length"
 #define SOURCE_OBJECT_VIDEO_FORMAT              "Format"
+#define SOURCE_OBJECT_VIDEO_CODEC               "Codec"
 #define SOURCE_OBJECT_AUDIO_FORMAT              "AudioFormat"
+#define SOURCE_OBJECT_AUDIO_CODEC               "AudioCodec"
 #define SOURCE_OBJECT_STATUS                    "Status"
 #define SOURCE_OBJECT_BITS                      "Bits"
 #define SOURCE_OBJECT_SAMPLE                    "Sample"
@@ -171,7 +200,9 @@
 #define SOURCE_OBJECT_PROPERTIES                "Properties"
 #define SOURCE_OBJECT_TRANSCODE                 "TranscodeInterface"
 #define SOURCE_OBJECT_AUTOTRANSCODE             "AutoTranscode"
+#define SOURCE_OBJECT_METASUBTITLES             "MetaSubtitles"
 #define SOURCE_OBJECT_SUBTITLES                 "Subtitles"
+#define SOURCE_OBJECT_AUDIO                     "Audio"
 
 #define SOURCE_PROPERTIES_POST                  "PostCommands"
 #define SOURCE_PROPERTIES_PRE                   "PreCommands"
@@ -189,17 +220,32 @@
 #define TRANSCODE_SAMPLE_RATE                   "SampleRate"
 #define TRANSCODE_STARTING_AT                   "StartingAt"
 #define TRANSCODE_ENDING_AT                     "EndingAt"
+#define TRANSCODE_REMUX_ONLY                    "RemuxOnly"
+#define TRANSCODE_SUBTITLE_FROM_META            "SubtitleFromMetaInfo"
 
-#define SUBTITLES_SUBTITLE_ENTRY                 "Entry"
-#define SUBTITLES_SUBTITLE_FILE                  "TempFile"
-#define SUBTITLES_FONT                           "Font"
-#define SUBTITLES_RECT                           "Rect"
-#define SUBTITLES_ALIGNMENT                      "Alignment"
-#define SUBTITLES_TRANSPARENCY                   "Transparency"
-#define SUBTITLES_COLORS                         "Colors"
-#define SUBTITLES_SUBTITLE_INDEX                 "Index"
-#define SUBTITLES_SUBTITLE_START                 "Start"
-#define SUBTITLES_SUBTITLE_STOP                  "Stop"
+#define SUBTITLES_SUBTITLE_ENTRY                "Entry"
+#define SUBTITLES_NUMBER                        "SubtitleNumber"
+#define SUBTITLES_LANG                          "Lang"
+#define SUBTITLES_SUBTITLE_FILE                 "TempFile"
+#define SUBTITLES_FONT                          "Font"
+#define SUBTITLES_FIT                           "Fit"
+#define SUBTITLES_STATE                         "State"
+#define SUBTITLES_TEXT_BASED                    "TextBased"
+#define SUBTITLES_TEXT_FONT                     "TextFont"
+#define SUBTITLES_TEXT_SIZE                     "TextSize"
+#define SUBTITLES_OUTLINE                       "Outline"
+#define SUBTITLES_RECT                          "Rect"
+#define SUBTITLES_ALIGNMENT                     "Alignment"
+#define SUBTITLES_COLORS                        "Colors"
+#define SUBTITLES_SUBTITLE_INDEX                "Index"
+#define SUBTITLES_SUBTITLE_START                "Start"
+#define SUBTITLES_SUBTITLE_STOP                 "Stop"
+// outdated now stored in COLOR (2007/11/07)
+#define SUBTITLES_TRANSPARENCY                  "Transparency"
+
+#define AUDIO_NUMBER                            "AudioNumber"
+#define AUDIO_LANGUAGE                          "Lang"
+#define AUDIO_FILE_NAME                         "FileName"
 
 // The Modifier - class - variables :
 #define MODIFIERS                               "Modifiers"
@@ -219,6 +265,10 @@
 #define MANIPULATOR_SHOW_BACKGROUND             "ShowBackground"
 #define MANIPULATOR_STARTX                      "StartX"
 #define MANIPULATOR_STARTY                      "StartY"
+#define MANIPULATOR_KENBURNS_X1                 "KenBurnsX1"
+#define MANIPULATOR_KENBURNS_Y1                 "KenBurnsY1"
+#define MANIPULATOR_KENBURNS_X2                 "KenBurnsX2"
+#define MANIPULATOR_KENBURNS_Y2                 "KenBurnsY2"
 #define MANIPULATOR_XRES                        "XRes"
 #define MANIPULATOR_YRES                        "YRes"
 #define MANIPULATOR_TRANSFORMATION_MODE	        "TransformationMode"
