@@ -1,6 +1,11 @@
-/////////////////
-// Hey
-////////////////
+/************************************************************
+  **
+  **   Created :
+  **        by : Varol Okan 
+  ** Copyright : (c) Varol Okan
+  **   License : GPL v 2.0
+  **
+  **********************************************************/
 #include "../bugs_workaround.h"
 #include "global.h"
 #include "xml_dvdauthor.h"
@@ -11,6 +16,14 @@
 #include <qstring.h>
 #include <qdom.h>
 
+#ifndef MAX_AUDIO
+#define MAX_AUDIO 8
+#endif
+
+#ifndef MAX_SUBTITLES
+#define MAX_SUBTITLES 32
+#endif
+
 #ifndef DEBUG_INFO
 #define debug_out printf
 #else
@@ -52,7 +65,7 @@ bool CXmlDVDAuthor::readXml (QString &fileName )
 {
 	// Assign the file
 	QFile projectFile(fileName);
-	if (!projectFile.open(IO_Raw | IO_ReadWrite))
+	if (!projectFile.open( IO_ReadWrite))
 		return false;
 
 	QDomDocument xmlDoc( DVD_DOCTYPE );
@@ -86,7 +99,6 @@ bool CXmlDVDAuthor::dvdauthor_struct::readXml(QDomElement *pDocElem)
 	dest = a.value();
 	a = pDocElem->attributeNode ( DVDAUTHOR_JUMPPAD );
 	jumppad = a.value();
-//printf ("CXmlDVDAuthor::dvdauthor_struct::readXml <%s><%s>\n",(const char *)a.name(), (const char *)a.value());
 
 	// And now read in all remaining nodes and handle them accordingly.
 	QDomNode xmlNode = pDocElem->firstChild();
@@ -110,7 +122,7 @@ bool CXmlDVDAuthor::dvdauthor_struct::readXml(QDomElement *pDocElem)
 
 bool CXmlDVDAuthor::vmgm_struct::readXml(QDomElement *pNodeElement)
 {
-	debug_out ("CXmlDVDAuthor::vmgm_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	debug_out ( "CXmlDVDAuthor::vmgm_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	bool bReturn = true;
 	// vmgm has no attributes thus far I can tell.
 	// And now read in all remaining nodes and handle them accordingly.
@@ -120,13 +132,15 @@ bool CXmlDVDAuthor::vmgm_struct::readXml(QDomElement *pNodeElement)
 	menus_struct *pNewMenus = NULL;
 	// And only one menus entry is allowed ...
 	while( !xmlNode.isNull() ) {
-		QDomElement searchTree = xmlNode.toElement();
-		if (searchTree.tagName() == tempMenus.node_name)	{
-			pNewMenus = addMenus ();
-			bReturn = pNewMenus->readXml(&searchTree);
+		QDomElement searchTree = xmlNode.toElement ( );
+		if ( searchTree.tagName ( ) == fpc.node_name )
+			bReturn = fpc.readXml ( &searchTree  );
+		if ( searchTree.tagName ( ) == tempMenus.node_name )  {
+			pNewMenus = addMenus ( );
+			bReturn = pNewMenus->readXml ( &searchTree );
 		}
 		// If there has been a problem then return false.
-		if (!bReturn)
+		if ( ! bReturn )
 			return false;
 		// Otherwise go to the next node ...
 		xmlNode = xmlNode.nextSibling();
@@ -170,6 +184,7 @@ bool CXmlDVDAuthor::menus_struct::readXml(QDomElement *pNodeElement)
 	debug_out ("CXmlDVDAuthor::menus_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	bool bReturn = true;
 	int iAudioChannel = 0;
+	int iSubpicture   = 0;
 	pgc_struct *pTempPGC = new pgc_struct();
 	pgc_struct *pNewPgc = NULL;
 	// Lets get the attributes first ...
@@ -184,10 +199,15 @@ bool CXmlDVDAuthor::menus_struct::readXml(QDomElement *pNodeElement)
 			bReturn = video.readXml(&searchTree);
 		else if (searchTree.tagName() == audio[iAudioChannel].node_name)	{
 			bReturn = audio[iAudioChannel].readXml(&searchTree);
-			iAudioChannel ++;
+			if ( ++iAudioChannel >= MAX_AUDIO )
+			  iAudioChannel = MAX_AUDIO-1;
+
+		}
+		else if (searchTree.tagName() == subpicture[iSubpicture].node_name) {
+		  bReturn = subpicture[iSubpicture].readXml(&searchTree);
+		  if ( ++iSubpicture >= MAX_SUBTITLES )
+		    iSubpicture = MAX_SUBTITLES-1;
 		}
-		else if (searchTree.tagName() == subpicture.node_name)
-			bReturn = subpicture.readXml(&searchTree);
 		else if (searchTree.tagName() == pTempPGC->node_name)	{
 			pNewPgc = addPgc ();
 			bReturn = pNewPgc->readXml(&searchTree);
@@ -251,6 +271,7 @@ bool CXmlDVDAuthor::titles_struct::readXml(QDomElement *pNodeElement)
 	debug_out ("CXmlDVDAuthor::titles_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	bool bReturn = true;
 	int iAudioChannel = 0;
+	int iSubpicture   = 0;
 	pgc_struct tempPGC;
 	pgc_struct *pNewPgc = NULL;
 	// And now read in all remaining nodes and handle them accordingly.
@@ -262,12 +283,19 @@ bool CXmlDVDAuthor::titles_struct::readXml(QDomElement *pNodeElement)
 			bReturn = video.readXml(&searchTree);
 		else if (searchTree.tagName() == audio[iAudioChannel].node_name)	{
 			bReturn = audio[iAudioChannel].readXml(&searchTree);
-			iAudioChannel ++;
+			if ( ++iAudioChannel > MAX_AUDIO )
+			  iAudioChannel = MAX_AUDIO - 1;
 		}
 		else if (searchTree.tagName() == tempPGC.node_name)	{
 			pNewPgc = addPgc ();
 			bReturn = pNewPgc->readXml(&searchTree);
 		}
+		else if (searchTree.tagName() == subpicture[iSubpicture].node_name)	{
+			bReturn = subpicture[iSubpicture].readXml(&searchTree);
+			if ( ++iSubpicture >= MAX_SUBTITLES )
+			  iSubpicture = MAX_SUBTITLES - 1;
+		}
+		
 		// If there has been a problem then return false.
 		if (!bReturn)
 			return false;
@@ -376,6 +404,14 @@ bool CXmlDVDAuthor::vob_struct::readXml(QDomElement *pNodeElement)
 	return bReturn;
 }
 
+bool CXmlDVDAuthor::fpc_struct::readXml ( QDomElement *pNodeElement )
+{
+	debug_out ("CXmlDVDAuthor::fpc_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	// read the commands to be executed before.
+	value = pNodeElement->text();
+	return true;
+}
+
 bool CXmlDVDAuthor::pre_struct::readXml(QDomElement *pNodeElement)
 {
 	debug_out ("CXmlDVDAuthor::pre_struct::readXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
@@ -643,6 +679,7 @@ bool CXmlDVDAuthor::vmgm_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	// And now proceed to writing the rest of the file.
 	pNodeElement->appendChild( vmgmNode );
 
+	bReturn = fpc.writeXml (pDocument, &vmgmNode);
 	if (ppArrayMenus)	{
 		while (ppArrayMenus[t])	{
 			if (!bReturn)
@@ -698,12 +735,17 @@ bool CXmlDVDAuthor::menus_struct::writeXml(QDomDocument *pDocument, QDomElement
 	bReturn = video.writeXml (pDocument, &menusNode);
 	if (!bReturn)
 		return false;
-	for (t=0;t<8;t++)	{
+
+	for ( t=0; t<MAX_AUDIO; t++ )	{
 		bReturn = audio[t].writeXml(pDocument, &menusNode);
 		if (!bReturn)
 			return false;
 	}
-	bReturn = subpicture.writeXml (pDocument, &menusNode);
+	for ( t=0;t<MAX_SUBTITLES; t++ ) {
+	  bReturn = subpicture[t].writeXml (pDocument, &menusNode);
+	  if ( ! bReturn )
+	    return false;
+	}
 	t = 0;
 	if (ppArrayPgc)	{
 		while (ppArrayPgc[t])	{
@@ -791,11 +833,16 @@ bool CXmlDVDAuthor::titles_struct::writeXml(QDomDocument *pDocument, QDomElement
 	bReturn = video.writeXml (pDocument, &titlesNode);
 	if (!bReturn)
 		return false;
-	for (t=0;t<8;t++)	{
+	for ( t=0; t<MAX_AUDIO; t++ )	{
 		bReturn = audio[t].writeXml(pDocument, &titlesNode);
 		if (!bReturn)
 			return false;
 	}
+	for ( t=0; t<MAX_SUBTITLES; t++ )	{
+		bReturn = subpicture[t].writeXml(pDocument, &titlesNode);
+		if (!bReturn)
+			return false;
+	}
 	t = 0;
 	if (ppArrayPgc)	{
 		while (ppArrayPgc[t])	{
@@ -903,11 +950,25 @@ bool CXmlDVDAuthor::vob_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	return cell.writeXml (pDocument, &vobNode);
 }
 
+bool CXmlDVDAuthor::fpc_struct::writeXml ( QDomDocument *pDocument, QDomElement *pNodeElement )
+{
+	// First check if this node holds any information at all ...
+	if ( value.isNull ( ) )
+		return true;
+	debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
+	QDomElement fpcNode = pDocument->createElement ( node_name );	// <fpc>
+	// And now proceed to writing the rest of the file.
+	pNodeElement->appendChild ( fpcNode );
+	QDomText domText = pDocument->createTextNode ( value );
+	fpcNode.appendChild ( domText );
+	return true;
+}
+
 bool CXmlDVDAuthor::pre_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
 	// First check if this node holds any information at all ...
-	if (value.isNull())
-		return true;
+	if ( value.isEmpty ( ) )
+	  return true;
 	debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement preNode = pDocument->createElement( node_name );	// <pre>
 	// And now proceed to writing the rest of the file.
@@ -920,8 +981,8 @@ bool CXmlDVDAuthor::pre_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 bool CXmlDVDAuthor::post_struct::writeXml(QDomDocument *pDocument, QDomElement *pNodeElement)
 {
 	// First check if this node holds any information at all ...
-	if (value.isNull())
-		return true;
+	if ( value.isEmpty ( ) )
+	  return true;
 	debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement postNode = pDocument->createElement( node_name );	// <post>
 	// And now proceed to writing the rest of the file.
@@ -958,7 +1019,7 @@ bool CXmlSpumux::readXml ( QString &fileName )
 {
   // Assign the file
   QFile projectFile(fileName);
-  if (!projectFile.open(IO_Raw | IO_ReadWrite))
+  if (!projectFile.open( IO_ReadWrite))
     return false;
   
   QDomDocument xmlDoc( DVD_DOCTYPE );
